# coding=utf-8
# *** WARNING: this file was generated by pulumi-language-python. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import builtins
import copy
import warnings
import sys
import pulumi
import pulumi.runtime
from typing import Any, Mapping, Optional, Sequence, Union, overload
if sys.version_info >= (3, 11):
    from typing import NotRequired, TypedDict, TypeAlias
else:
    from typing_extensions import NotRequired, TypedDict, TypeAlias
from .. import _utilities

__all__ = [
    'GetUserS3CredentialResult',
    'AwaitableGetUserS3CredentialResult',
    'get_user_s3_credential',
    'get_user_s3_credential_output',
]

@pulumi.output_type
class GetUserS3CredentialResult:
    """
    A collection of values returned by getUserS3Credential.
    """
    def __init__(__self__, access_key_id=None, id=None, secret_access_key=None, service_name=None, user_id=None):
        if access_key_id and not isinstance(access_key_id, str):
            raise TypeError("Expected argument 'access_key_id' to be a str")
        pulumi.set(__self__, "access_key_id", access_key_id)
        if id and not isinstance(id, str):
            raise TypeError("Expected argument 'id' to be a str")
        pulumi.set(__self__, "id", id)
        if secret_access_key and not isinstance(secret_access_key, str):
            raise TypeError("Expected argument 'secret_access_key' to be a str")
        pulumi.set(__self__, "secret_access_key", secret_access_key)
        if service_name and not isinstance(service_name, str):
            raise TypeError("Expected argument 'service_name' to be a str")
        pulumi.set(__self__, "service_name", service_name)
        if user_id and not isinstance(user_id, str):
            raise TypeError("Expected argument 'user_id' to be a str")
        pulumi.set(__self__, "user_id", user_id)

    @property
    @pulumi.getter(name="accessKeyId")
    def access_key_id(self) -> builtins.str:
        return pulumi.get(self, "access_key_id")

    @property
    @pulumi.getter
    def id(self) -> builtins.str:
        """
        The provider-assigned unique ID for this managed resource.
        """
        return pulumi.get(self, "id")

    @property
    @pulumi.getter(name="secretAccessKey")
    def secret_access_key(self) -> builtins.str:
        """
        (Sensitive) the Secret Access Key
        """
        return pulumi.get(self, "secret_access_key")

    @property
    @pulumi.getter(name="serviceName")
    def service_name(self) -> builtins.str:
        return pulumi.get(self, "service_name")

    @property
    @pulumi.getter(name="userId")
    def user_id(self) -> builtins.str:
        return pulumi.get(self, "user_id")


class AwaitableGetUserS3CredentialResult(GetUserS3CredentialResult):
    # pylint: disable=using-constant-test
    def __await__(self):
        if False:
            yield self
        return GetUserS3CredentialResult(
            access_key_id=self.access_key_id,
            id=self.id,
            secret_access_key=self.secret_access_key,
            service_name=self.service_name,
            user_id=self.user_id)


def get_user_s3_credential(access_key_id: Optional[builtins.str] = None,
                           service_name: Optional[builtins.str] = None,
                           user_id: Optional[builtins.str] = None,
                           opts: Optional[pulumi.InvokeOptions] = None) -> AwaitableGetUserS3CredentialResult:
    """
    Use this data source to retrieve the Secret Access Key of an Access Key ID associated with a public cloud project's user.

    ## Example Usage

    ```python
    import pulumi
    import pulumi_ovh as ovh

    project_users = ovh.CloudProject.get_users(service_name="XXX")
    # Get the user ID of a previously created user with the description "S3-User"
    users = [user.user_id for user in project_users.users if user.description == "S3-User"]
    s3_user_id = users[0]
    my_s3_credentials = ovh.CloudProject.get_user_s3_credentials(service_name=project_users.service_name,
        user_id=s3_user_id)
    my_s3_credential = ovh.CloudProject.get_user_s3_credential(service_name=my_s3_credentials.service_name,
        user_id=my_s3_credentials.user_id,
        access_key_id=my_s3_credentials.access_key_ids[0])
    pulumi.export("myAccessKeyId", my_s3_credential.access_key_id)
    pulumi.export("mySecretAccessKey", my_s3_credential.secret_access_key)
    ```


    :param builtins.str access_key_id: the Access Key ID
    :param builtins.str service_name: The ID of the public cloud project. If omitted, the `OVH_CLOUD_PROJECT_SERVICE` environment variable is used.
    :param builtins.str user_id: The ID of a public cloud project's user.
    """
    __args__ = dict()
    __args__['accessKeyId'] = access_key_id
    __args__['serviceName'] = service_name
    __args__['userId'] = user_id
    opts = pulumi.InvokeOptions.merge(_utilities.get_invoke_opts_defaults(), opts)
    __ret__ = pulumi.runtime.invoke('ovh:CloudProject/getUserS3Credential:getUserS3Credential', __args__, opts=opts, typ=GetUserS3CredentialResult).value

    return AwaitableGetUserS3CredentialResult(
        access_key_id=pulumi.get(__ret__, 'access_key_id'),
        id=pulumi.get(__ret__, 'id'),
        secret_access_key=pulumi.get(__ret__, 'secret_access_key'),
        service_name=pulumi.get(__ret__, 'service_name'),
        user_id=pulumi.get(__ret__, 'user_id'))
def get_user_s3_credential_output(access_key_id: Optional[pulumi.Input[builtins.str]] = None,
                                  service_name: Optional[pulumi.Input[builtins.str]] = None,
                                  user_id: Optional[pulumi.Input[builtins.str]] = None,
                                  opts: Optional[Union[pulumi.InvokeOptions, pulumi.InvokeOutputOptions]] = None) -> pulumi.Output[GetUserS3CredentialResult]:
    """
    Use this data source to retrieve the Secret Access Key of an Access Key ID associated with a public cloud project's user.

    ## Example Usage

    ```python
    import pulumi
    import pulumi_ovh as ovh

    project_users = ovh.CloudProject.get_users(service_name="XXX")
    # Get the user ID of a previously created user with the description "S3-User"
    users = [user.user_id for user in project_users.users if user.description == "S3-User"]
    s3_user_id = users[0]
    my_s3_credentials = ovh.CloudProject.get_user_s3_credentials(service_name=project_users.service_name,
        user_id=s3_user_id)
    my_s3_credential = ovh.CloudProject.get_user_s3_credential(service_name=my_s3_credentials.service_name,
        user_id=my_s3_credentials.user_id,
        access_key_id=my_s3_credentials.access_key_ids[0])
    pulumi.export("myAccessKeyId", my_s3_credential.access_key_id)
    pulumi.export("mySecretAccessKey", my_s3_credential.secret_access_key)
    ```


    :param builtins.str access_key_id: the Access Key ID
    :param builtins.str service_name: The ID of the public cloud project. If omitted, the `OVH_CLOUD_PROJECT_SERVICE` environment variable is used.
    :param builtins.str user_id: The ID of a public cloud project's user.
    """
    __args__ = dict()
    __args__['accessKeyId'] = access_key_id
    __args__['serviceName'] = service_name
    __args__['userId'] = user_id
    opts = pulumi.InvokeOutputOptions.merge(_utilities.get_invoke_opts_defaults(), opts)
    __ret__ = pulumi.runtime.invoke_output('ovh:CloudProject/getUserS3Credential:getUserS3Credential', __args__, opts=opts, typ=GetUserS3CredentialResult)
    return __ret__.apply(lambda __response__: GetUserS3CredentialResult(
        access_key_id=pulumi.get(__response__, 'access_key_id'),
        id=pulumi.get(__response__, 'id'),
        secret_access_key=pulumi.get(__response__, 'secret_access_key'),
        service_name=pulumi.get(__response__, 'service_name'),
        user_id=pulumi.get(__response__, 'user_id')))



# coding=utf-8
# *** WARNING: this file was generated by pulumi-language-python. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import builtins
import copy
import warnings
import sys
import pulumi
import pulumi.runtime
from typing import Any, Mapping, Optional, Sequence, Union, overload
if sys.version_info >= (3, 11):
    from typing import NotRequired, TypedDict, TypeAlias
else:
    from typing_extensions import NotRequired, TypedDict, TypeAlias
from .. import _utilities

__all__ = ['APIOAuth2ClientArgs', 'APIOAuth2Client']

@pulumi.input_type
class APIOAuth2ClientArgs:
    def __init__(__self__, *,
                 description: pulumi.Input[builtins.str],
                 flow: pulumi.Input[builtins.str],
                 callback_urls: Optional[pulumi.Input[Sequence[pulumi.Input[builtins.str]]]] = None,
                 name: Optional[pulumi.Input[builtins.str]] = None):
        """
        The set of arguments for constructing a APIOAuth2Client resource.
        :param pulumi.Input[builtins.str] description: OAuth2 client description.
        :param pulumi.Input[builtins.str] flow: The OAuth2 flow to use. `AUTHORIZATION_CODE` or `CLIENT_CREDENTIALS` are supported at the moment.
        :param pulumi.Input[Sequence[pulumi.Input[builtins.str]]] callback_urls: List of callback urls when configuring the `AUTHORIZATION_CODE` flow.
        :param pulumi.Input[builtins.str] name: OAuth2 client name.
        """
        pulumi.set(__self__, "description", description)
        pulumi.set(__self__, "flow", flow)
        if callback_urls is not None:
            pulumi.set(__self__, "callback_urls", callback_urls)
        if name is not None:
            pulumi.set(__self__, "name", name)

    @property
    @pulumi.getter
    def description(self) -> pulumi.Input[builtins.str]:
        """
        OAuth2 client description.
        """
        return pulumi.get(self, "description")

    @description.setter
    def description(self, value: pulumi.Input[builtins.str]):
        pulumi.set(self, "description", value)

    @property
    @pulumi.getter
    def flow(self) -> pulumi.Input[builtins.str]:
        """
        The OAuth2 flow to use. `AUTHORIZATION_CODE` or `CLIENT_CREDENTIALS` are supported at the moment.
        """
        return pulumi.get(self, "flow")

    @flow.setter
    def flow(self, value: pulumi.Input[builtins.str]):
        pulumi.set(self, "flow", value)

    @property
    @pulumi.getter(name="callbackUrls")
    def callback_urls(self) -> Optional[pulumi.Input[Sequence[pulumi.Input[builtins.str]]]]:
        """
        List of callback urls when configuring the `AUTHORIZATION_CODE` flow.
        """
        return pulumi.get(self, "callback_urls")

    @callback_urls.setter
    def callback_urls(self, value: Optional[pulumi.Input[Sequence[pulumi.Input[builtins.str]]]]):
        pulumi.set(self, "callback_urls", value)

    @property
    @pulumi.getter
    def name(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        OAuth2 client name.
        """
        return pulumi.get(self, "name")

    @name.setter
    def name(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "name", value)


@pulumi.input_type
class _APIOAuth2ClientState:
    def __init__(__self__, *,
                 callback_urls: Optional[pulumi.Input[Sequence[pulumi.Input[builtins.str]]]] = None,
                 client_id: Optional[pulumi.Input[builtins.str]] = None,
                 client_secret: Optional[pulumi.Input[builtins.str]] = None,
                 description: Optional[pulumi.Input[builtins.str]] = None,
                 flow: Optional[pulumi.Input[builtins.str]] = None,
                 identity: Optional[pulumi.Input[builtins.str]] = None,
                 name: Optional[pulumi.Input[builtins.str]] = None):
        """
        Input properties used for looking up and filtering APIOAuth2Client resources.
        :param pulumi.Input[Sequence[pulumi.Input[builtins.str]]] callback_urls: List of callback urls when configuring the `AUTHORIZATION_CODE` flow.
        :param pulumi.Input[builtins.str] client_id: Client ID of the created service account.
        :param pulumi.Input[builtins.str] client_secret: Client secret of the created service account.
        :param pulumi.Input[builtins.str] description: OAuth2 client description.
        :param pulumi.Input[builtins.str] flow: The OAuth2 flow to use. `AUTHORIZATION_CODE` or `CLIENT_CREDENTIALS` are supported at the moment.
        :param pulumi.Input[builtins.str] identity: URN that will allow you to associate this oauth2 client with an access policy
        :param pulumi.Input[builtins.str] name: OAuth2 client name.
        """
        if callback_urls is not None:
            pulumi.set(__self__, "callback_urls", callback_urls)
        if client_id is not None:
            pulumi.set(__self__, "client_id", client_id)
        if client_secret is not None:
            pulumi.set(__self__, "client_secret", client_secret)
        if description is not None:
            pulumi.set(__self__, "description", description)
        if flow is not None:
            pulumi.set(__self__, "flow", flow)
        if identity is not None:
            pulumi.set(__self__, "identity", identity)
        if name is not None:
            pulumi.set(__self__, "name", name)

    @property
    @pulumi.getter(name="callbackUrls")
    def callback_urls(self) -> Optional[pulumi.Input[Sequence[pulumi.Input[builtins.str]]]]:
        """
        List of callback urls when configuring the `AUTHORIZATION_CODE` flow.
        """
        return pulumi.get(self, "callback_urls")

    @callback_urls.setter
    def callback_urls(self, value: Optional[pulumi.Input[Sequence[pulumi.Input[builtins.str]]]]):
        pulumi.set(self, "callback_urls", value)

    @property
    @pulumi.getter(name="clientId")
    def client_id(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        Client ID of the created service account.
        """
        return pulumi.get(self, "client_id")

    @client_id.setter
    def client_id(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "client_id", value)

    @property
    @pulumi.getter(name="clientSecret")
    def client_secret(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        Client secret of the created service account.
        """
        return pulumi.get(self, "client_secret")

    @client_secret.setter
    def client_secret(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "client_secret", value)

    @property
    @pulumi.getter
    def description(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        OAuth2 client description.
        """
        return pulumi.get(self, "description")

    @description.setter
    def description(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "description", value)

    @property
    @pulumi.getter
    def flow(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        The OAuth2 flow to use. `AUTHORIZATION_CODE` or `CLIENT_CREDENTIALS` are supported at the moment.
        """
        return pulumi.get(self, "flow")

    @flow.setter
    def flow(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "flow", value)

    @property
    @pulumi.getter
    def identity(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        URN that will allow you to associate this oauth2 client with an access policy
        """
        return pulumi.get(self, "identity")

    @identity.setter
    def identity(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "identity", value)

    @property
    @pulumi.getter
    def name(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        OAuth2 client name.
        """
        return pulumi.get(self, "name")

    @name.setter
    def name(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "name", value)


@pulumi.type_token("ovh:Me/aPIOAuth2Client:APIOAuth2Client")
class APIOAuth2Client(pulumi.CustomResource):
    @overload
    def __init__(__self__,
                 resource_name: str,
                 opts: Optional[pulumi.ResourceOptions] = None,
                 callback_urls: Optional[pulumi.Input[Sequence[pulumi.Input[builtins.str]]]] = None,
                 description: Optional[pulumi.Input[builtins.str]] = None,
                 flow: Optional[pulumi.Input[builtins.str]] = None,
                 name: Optional[pulumi.Input[builtins.str]] = None,
                 __props__=None):
        """
        Creates an OAuth2 service account.

        ## Example Usage

        An OAuth2 client for an app hosted at `my-app.com`, that uses the authorization code flow to authenticate.

        ```python
        import pulumi
        import pulumi_ovh as ovh

        my_oauth2_client_auth_code = ovh.me.APIOAuth2Client("my_oauth2_client_auth_code",
            name="OAuth2 authorization code service account",
            flow="AUTHORIZATION_CODE",
            description="An OAuth2 client using the authorization code flow for my-app.com",
            callback_urls=["https://my-app.com/callback"])
        ```

        An OAuth2 client for an app hosted at `my-app.com`, that uses the client credentials flow to authenticate.

        ```python
        import pulumi
        import pulumi_ovh as ovh

        my_oauth2_client_client_creds = ovh.me.APIOAuth2Client("my_oauth2_client_client_creds",
            name="client credentials service account",
            description="An OAuth2 client using the client credentials flow for my app",
            flow="CLIENT_CREDENTIALS")
        ```

        ## Import

        OAuth2 clients can be imported using their `client_id`:

        bash

        ```sh
        $ pulumi import ovh:Me/aPIOAuth2Client:APIOAuth2Client my_oauth2_client client_id
        ```

        Because the client_secret is only available for resources created using terraform, OAuth2 clients can also be imported using a `client_id` and a `client_secret` with a pipe separator:

        bash

        ```sh
        $ pulumi import ovh:Me/aPIOAuth2Client:APIOAuth2Client my_oauth2_client 'client_id|client_secret'
        ```

        :param str resource_name: The name of the resource.
        :param pulumi.ResourceOptions opts: Options for the resource.
        :param pulumi.Input[Sequence[pulumi.Input[builtins.str]]] callback_urls: List of callback urls when configuring the `AUTHORIZATION_CODE` flow.
        :param pulumi.Input[builtins.str] description: OAuth2 client description.
        :param pulumi.Input[builtins.str] flow: The OAuth2 flow to use. `AUTHORIZATION_CODE` or `CLIENT_CREDENTIALS` are supported at the moment.
        :param pulumi.Input[builtins.str] name: OAuth2 client name.
        """
        ...
    @overload
    def __init__(__self__,
                 resource_name: str,
                 args: APIOAuth2ClientArgs,
                 opts: Optional[pulumi.ResourceOptions] = None):
        """
        Creates an OAuth2 service account.

        ## Example Usage

        An OAuth2 client for an app hosted at `my-app.com`, that uses the authorization code flow to authenticate.

        ```python
        import pulumi
        import pulumi_ovh as ovh

        my_oauth2_client_auth_code = ovh.me.APIOAuth2Client("my_oauth2_client_auth_code",
            name="OAuth2 authorization code service account",
            flow="AUTHORIZATION_CODE",
            description="An OAuth2 client using the authorization code flow for my-app.com",
            callback_urls=["https://my-app.com/callback"])
        ```

        An OAuth2 client for an app hosted at `my-app.com`, that uses the client credentials flow to authenticate.

        ```python
        import pulumi
        import pulumi_ovh as ovh

        my_oauth2_client_client_creds = ovh.me.APIOAuth2Client("my_oauth2_client_client_creds",
            name="client credentials service account",
            description="An OAuth2 client using the client credentials flow for my app",
            flow="CLIENT_CREDENTIALS")
        ```

        ## Import

        OAuth2 clients can be imported using their `client_id`:

        bash

        ```sh
        $ pulumi import ovh:Me/aPIOAuth2Client:APIOAuth2Client my_oauth2_client client_id
        ```

        Because the client_secret is only available for resources created using terraform, OAuth2 clients can also be imported using a `client_id` and a `client_secret` with a pipe separator:

        bash

        ```sh
        $ pulumi import ovh:Me/aPIOAuth2Client:APIOAuth2Client my_oauth2_client 'client_id|client_secret'
        ```

        :param str resource_name: The name of the resource.
        :param APIOAuth2ClientArgs args: The arguments to use to populate this resource's properties.
        :param pulumi.ResourceOptions opts: Options for the resource.
        """
        ...
    def __init__(__self__, resource_name: str, *args, **kwargs):
        resource_args, opts = _utilities.get_resource_args_opts(APIOAuth2ClientArgs, pulumi.ResourceOptions, *args, **kwargs)
        if resource_args is not None:
            __self__._internal_init(resource_name, opts, **resource_args.__dict__)
        else:
            __self__._internal_init(resource_name, *args, **kwargs)

    def _internal_init(__self__,
                 resource_name: str,
                 opts: Optional[pulumi.ResourceOptions] = None,
                 callback_urls: Optional[pulumi.Input[Sequence[pulumi.Input[builtins.str]]]] = None,
                 description: Optional[pulumi.Input[builtins.str]] = None,
                 flow: Optional[pulumi.Input[builtins.str]] = None,
                 name: Optional[pulumi.Input[builtins.str]] = None,
                 __props__=None):
        opts = pulumi.ResourceOptions.merge(_utilities.get_resource_opts_defaults(), opts)
        if not isinstance(opts, pulumi.ResourceOptions):
            raise TypeError('Expected resource options to be a ResourceOptions instance')
        if opts.id is None:
            if __props__ is not None:
                raise TypeError('__props__ is only valid when passed in combination with a valid opts.id to get an existing resource')
            __props__ = APIOAuth2ClientArgs.__new__(APIOAuth2ClientArgs)

            __props__.__dict__["callback_urls"] = callback_urls
            if description is None and not opts.urn:
                raise TypeError("Missing required property 'description'")
            __props__.__dict__["description"] = description
            if flow is None and not opts.urn:
                raise TypeError("Missing required property 'flow'")
            __props__.__dict__["flow"] = flow
            __props__.__dict__["name"] = name
            __props__.__dict__["client_id"] = None
            __props__.__dict__["client_secret"] = None
            __props__.__dict__["identity"] = None
        secret_opts = pulumi.ResourceOptions(additional_secret_outputs=["clientSecret"])
        opts = pulumi.ResourceOptions.merge(opts, secret_opts)
        super(APIOAuth2Client, __self__).__init__(
            'ovh:Me/aPIOAuth2Client:APIOAuth2Client',
            resource_name,
            __props__,
            opts)

    @staticmethod
    def get(resource_name: str,
            id: pulumi.Input[str],
            opts: Optional[pulumi.ResourceOptions] = None,
            callback_urls: Optional[pulumi.Input[Sequence[pulumi.Input[builtins.str]]]] = None,
            client_id: Optional[pulumi.Input[builtins.str]] = None,
            client_secret: Optional[pulumi.Input[builtins.str]] = None,
            description: Optional[pulumi.Input[builtins.str]] = None,
            flow: Optional[pulumi.Input[builtins.str]] = None,
            identity: Optional[pulumi.Input[builtins.str]] = None,
            name: Optional[pulumi.Input[builtins.str]] = None) -> 'APIOAuth2Client':
        """
        Get an existing APIOAuth2Client resource's state with the given name, id, and optional extra
        properties used to qualify the lookup.

        :param str resource_name: The unique name of the resulting resource.
        :param pulumi.Input[str] id: The unique provider ID of the resource to lookup.
        :param pulumi.ResourceOptions opts: Options for the resource.
        :param pulumi.Input[Sequence[pulumi.Input[builtins.str]]] callback_urls: List of callback urls when configuring the `AUTHORIZATION_CODE` flow.
        :param pulumi.Input[builtins.str] client_id: Client ID of the created service account.
        :param pulumi.Input[builtins.str] client_secret: Client secret of the created service account.
        :param pulumi.Input[builtins.str] description: OAuth2 client description.
        :param pulumi.Input[builtins.str] flow: The OAuth2 flow to use. `AUTHORIZATION_CODE` or `CLIENT_CREDENTIALS` are supported at the moment.
        :param pulumi.Input[builtins.str] identity: URN that will allow you to associate this oauth2 client with an access policy
        :param pulumi.Input[builtins.str] name: OAuth2 client name.
        """
        opts = pulumi.ResourceOptions.merge(opts, pulumi.ResourceOptions(id=id))

        __props__ = _APIOAuth2ClientState.__new__(_APIOAuth2ClientState)

        __props__.__dict__["callback_urls"] = callback_urls
        __props__.__dict__["client_id"] = client_id
        __props__.__dict__["client_secret"] = client_secret
        __props__.__dict__["description"] = description
        __props__.__dict__["flow"] = flow
        __props__.__dict__["identity"] = identity
        __props__.__dict__["name"] = name
        return APIOAuth2Client(resource_name, opts=opts, __props__=__props__)

    @property
    @pulumi.getter(name="callbackUrls")
    def callback_urls(self) -> pulumi.Output[Optional[Sequence[builtins.str]]]:
        """
        List of callback urls when configuring the `AUTHORIZATION_CODE` flow.
        """
        return pulumi.get(self, "callback_urls")

    @property
    @pulumi.getter(name="clientId")
    def client_id(self) -> pulumi.Output[builtins.str]:
        """
        Client ID of the created service account.
        """
        return pulumi.get(self, "client_id")

    @property
    @pulumi.getter(name="clientSecret")
    def client_secret(self) -> pulumi.Output[builtins.str]:
        """
        Client secret of the created service account.
        """
        return pulumi.get(self, "client_secret")

    @property
    @pulumi.getter
    def description(self) -> pulumi.Output[builtins.str]:
        """
        OAuth2 client description.
        """
        return pulumi.get(self, "description")

    @property
    @pulumi.getter
    def flow(self) -> pulumi.Output[builtins.str]:
        """
        The OAuth2 flow to use. `AUTHORIZATION_CODE` or `CLIENT_CREDENTIALS` are supported at the moment.
        """
        return pulumi.get(self, "flow")

    @property
    @pulumi.getter
    def identity(self) -> pulumi.Output[builtins.str]:
        """
        URN that will allow you to associate this oauth2 client with an access policy
        """
        return pulumi.get(self, "identity")

    @property
    @pulumi.getter
    def name(self) -> pulumi.Output[builtins.str]:
        """
        OAuth2 client name.
        """
        return pulumi.get(self, "name")




# coding=utf-8
# *** WARNING: this file was generated by pulumi-language-python. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import builtins
import copy
import warnings
import sys
import pulumi
import pulumi.runtime
from typing import Any, Mapping, Optional, Sequence, Union, overload
if sys.version_info >= (3, 11):
    from typing import NotRequired, TypedDict, TypeAlias
else:
    from typing_extensions import NotRequired, TypedDict, TypeAlias
from .. import _utilities
from . import outputs

__all__ = [
    'GetUserResult',
    'AwaitableGetUserResult',
    'get_user',
    'get_user_output',
]

@pulumi.output_type
class GetUserResult:
    """
    A collection of values returned by getUser.
    """
    def __init__(__self__, creation_date=None, description=None, id=None, roles=None, service_name=None, status=None, user_id=None, username=None):
        if creation_date and not isinstance(creation_date, str):
            raise TypeError("Expected argument 'creation_date' to be a str")
        pulumi.set(__self__, "creation_date", creation_date)
        if description and not isinstance(description, str):
            raise TypeError("Expected argument 'description' to be a str")
        pulumi.set(__self__, "description", description)
        if id and not isinstance(id, str):
            raise TypeError("Expected argument 'id' to be a str")
        pulumi.set(__self__, "id", id)
        if roles and not isinstance(roles, list):
            raise TypeError("Expected argument 'roles' to be a list")
        pulumi.set(__self__, "roles", roles)
        if service_name and not isinstance(service_name, str):
            raise TypeError("Expected argument 'service_name' to be a str")
        pulumi.set(__self__, "service_name", service_name)
        if status and not isinstance(status, str):
            raise TypeError("Expected argument 'status' to be a str")
        pulumi.set(__self__, "status", status)
        if user_id and not isinstance(user_id, str):
            raise TypeError("Expected argument 'user_id' to be a str")
        pulumi.set(__self__, "user_id", user_id)
        if username and not isinstance(username, str):
            raise TypeError("Expected argument 'username' to be a str")
        pulumi.set(__self__, "username", username)

    @property
    @pulumi.getter(name="creationDate")
    def creation_date(self) -> builtins.str:
        """
        the date the user was created.
        """
        return pulumi.get(self, "creation_date")

    @property
    @pulumi.getter
    def description(self) -> builtins.str:
        """
        description of the role
        """
        return pulumi.get(self, "description")

    @property
    @pulumi.getter
    def id(self) -> builtins.str:
        """
        The provider-assigned unique ID for this managed resource.
        """
        return pulumi.get(self, "id")

    @property
    @pulumi.getter
    def roles(self) -> Sequence['outputs.GetUserRoleResult']:
        """
        A list of roles associated with the user.
        """
        return pulumi.get(self, "roles")

    @property
    @pulumi.getter(name="serviceName")
    def service_name(self) -> builtins.str:
        return pulumi.get(self, "service_name")

    @property
    @pulumi.getter
    def status(self) -> builtins.str:
        """
        the status of the user. should be normally set to 'ok'.
        """
        return pulumi.get(self, "status")

    @property
    @pulumi.getter(name="userId")
    def user_id(self) -> builtins.str:
        return pulumi.get(self, "user_id")

    @property
    @pulumi.getter
    def username(self) -> builtins.str:
        """
        the username generated for the user. This username can be used with the Openstack API.
        """
        return pulumi.get(self, "username")


class AwaitableGetUserResult(GetUserResult):
    # pylint: disable=using-constant-test
    def __await__(self):
        if False:
            yield self
        return GetUserResult(
            creation_date=self.creation_date,
            description=self.description,
            id=self.id,
            roles=self.roles,
            service_name=self.service_name,
            status=self.status,
            user_id=self.user_id,
            username=self.username)


def get_user(service_name: Optional[builtins.str] = None,
             user_id: Optional[builtins.str] = None,
             opts: Optional[pulumi.InvokeOptions] = None) -> AwaitableGetUserResult:
    """
    Get the user details of a previously created public cloud project user.

    ## Example Usage

    ```python
    import pulumi
    import pulumi_ovh as ovh

    project_users = ovh.CloudProject.get_users(service_name="XXX")
    # Get the user ID of a previously created user with the description "S3-User"
    users = [user.user_id for user in project_users.users if user.description == "S3-User"]
    s3_user_id = users[0]
    my_user = ovh.CloudProject.get_user(service_name=project_users.service_name,
        user_id=s3_user_id)
    ```


    :param builtins.str service_name: The ID of the public cloud project. If omitted, the `OVH_CLOUD_PROJECT_SERVICE` environment variable is used.
    :param builtins.str user_id: The ID of a public cloud project's user.
    """
    __args__ = dict()
    __args__['serviceName'] = service_name
    __args__['userId'] = user_id
    opts = pulumi.InvokeOptions.merge(_utilities.get_invoke_opts_defaults(), opts)
    __ret__ = pulumi.runtime.invoke('ovh:CloudProject/getUser:getUser', __args__, opts=opts, typ=GetUserResult).value

    return AwaitableGetUserResult(
        creation_date=pulumi.get(__ret__, 'creation_date'),
        description=pulumi.get(__ret__, 'description'),
        id=pulumi.get(__ret__, 'id'),
        roles=pulumi.get(__ret__, 'roles'),
        service_name=pulumi.get(__ret__, 'service_name'),
        status=pulumi.get(__ret__, 'status'),
        user_id=pulumi.get(__ret__, 'user_id'),
        username=pulumi.get(__ret__, 'username'))
def get_user_output(service_name: Optional[pulumi.Input[builtins.str]] = None,
                    user_id: Optional[pulumi.Input[builtins.str]] = None,
                    opts: Optional[Union[pulumi.InvokeOptions, pulumi.InvokeOutputOptions]] = None) -> pulumi.Output[GetUserResult]:
    """
    Get the user details of a previously created public cloud project user.

    ## Example Usage

    ```python
    import pulumi
    import pulumi_ovh as ovh

    project_users = ovh.CloudProject.get_users(service_name="XXX")
    # Get the user ID of a previously created user with the description "S3-User"
    users = [user.user_id for user in project_users.users if user.description == "S3-User"]
    s3_user_id = users[0]
    my_user = ovh.CloudProject.get_user(service_name=project_users.service_name,
        user_id=s3_user_id)
    ```


    :param builtins.str service_name: The ID of the public cloud project. If omitted, the `OVH_CLOUD_PROJECT_SERVICE` environment variable is used.
    :param builtins.str user_id: The ID of a public cloud project's user.
    """
    __args__ = dict()
    __args__['serviceName'] = service_name
    __args__['userId'] = user_id
    opts = pulumi.InvokeOutputOptions.merge(_utilities.get_invoke_opts_defaults(), opts)
    __ret__ = pulumi.runtime.invoke_output('ovh:CloudProject/getUser:getUser', __args__, opts=opts, typ=GetUserResult)
    return __ret__.apply(lambda __response__: GetUserResult(
        creation_date=pulumi.get(__response__, 'creation_date'),
        description=pulumi.get(__response__, 'description'),
        id=pulumi.get(__response__, 'id'),
        roles=pulumi.get(__response__, 'roles'),
        service_name=pulumi.get(__response__, 'service_name'),
        status=pulumi.get(__response__, 'status'),
        user_id=pulumi.get(__response__, 'user_id'),
        username=pulumi.get(__response__, 'username')))



# coding=utf-8
# *** WARNING: this file was generated by pulumi-language-python. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import builtins
import copy
import warnings
import sys
import pulumi
import pulumi.runtime
from typing import Any, Mapping, Optional, Sequence, Union, overload
if sys.version_info >= (3, 11):
    from typing import NotRequired, TypedDict, TypeAlias
else:
    from typing_extensions import NotRequired, TypedDict, TypeAlias
from .. import _utilities

__all__ = ['CloudProjectArgs', 'CloudProject']

@pulumi.input_type
class CloudProjectArgs:
    def __init__(__self__, *,
                 project_id: Optional[pulumi.Input[builtins.str]] = None,
                 service_name: Optional[pulumi.Input[builtins.str]] = None):
        """
        The set of arguments for constructing a CloudProject resource.
        :param pulumi.Input[builtins.str] project_id: The id of the public cloud project. If omitted, the `OVH_CLOUD_PROJECT_SERVICE` environment variable is used.
        :param pulumi.Input[builtins.str] service_name: The service name of the vrack. If omitted, the `OVH_VRACK_SERVICE` environment variable is used.
        """
        if project_id is not None:
            pulumi.set(__self__, "project_id", project_id)
        if service_name is not None:
            pulumi.set(__self__, "service_name", service_name)

    @property
    @pulumi.getter(name="projectId")
    def project_id(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        The id of the public cloud project. If omitted, the `OVH_CLOUD_PROJECT_SERVICE` environment variable is used.
        """
        return pulumi.get(self, "project_id")

    @project_id.setter
    def project_id(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "project_id", value)

    @property
    @pulumi.getter(name="serviceName")
    def service_name(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        The service name of the vrack. If omitted, the `OVH_VRACK_SERVICE` environment variable is used.
        """
        return pulumi.get(self, "service_name")

    @service_name.setter
    def service_name(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "service_name", value)


@pulumi.input_type
class _CloudProjectState:
    def __init__(__self__, *,
                 project_id: Optional[pulumi.Input[builtins.str]] = None,
                 service_name: Optional[pulumi.Input[builtins.str]] = None):
        """
        Input properties used for looking up and filtering CloudProject resources.
        :param pulumi.Input[builtins.str] project_id: The id of the public cloud project. If omitted, the `OVH_CLOUD_PROJECT_SERVICE` environment variable is used.
        :param pulumi.Input[builtins.str] service_name: The service name of the vrack. If omitted, the `OVH_VRACK_SERVICE` environment variable is used.
        """
        if project_id is not None:
            pulumi.set(__self__, "project_id", project_id)
        if service_name is not None:
            pulumi.set(__self__, "service_name", service_name)

    @property
    @pulumi.getter(name="projectId")
    def project_id(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        The id of the public cloud project. If omitted, the `OVH_CLOUD_PROJECT_SERVICE` environment variable is used.
        """
        return pulumi.get(self, "project_id")

    @project_id.setter
    def project_id(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "project_id", value)

    @property
    @pulumi.getter(name="serviceName")
    def service_name(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        The service name of the vrack. If omitted, the `OVH_VRACK_SERVICE` environment variable is used.
        """
        return pulumi.get(self, "service_name")

    @service_name.setter
    def service_name(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "service_name", value)


@pulumi.type_token("ovh:Vrack/cloudProject:CloudProject")
class CloudProject(pulumi.CustomResource):
    @overload
    def __init__(__self__,
                 resource_name: str,
                 opts: Optional[pulumi.ResourceOptions] = None,
                 project_id: Optional[pulumi.Input[builtins.str]] = None,
                 service_name: Optional[pulumi.Input[builtins.str]] = None,
                 __props__=None):
        """
        Attach a Public Cloud Project to a VRack.

        ## Example Usage

        ```python
        import pulumi
        import pulumi_ovh as ovh

        vcp = ovh.vrack.CloudProject("vcp",
            service_name="12345",
            project_id="67890")
        ```

        ## Import

        Attachment of a public cloud project and a VRack can be imported using the `service_name` (vRack identifier) and the `project_id` (Cloud Project identifier), separated by "/" E.g.,

        bash

        ```sh
        $ pulumi import ovh:Vrack/cloudProject:CloudProject myattach service_name/project_id
        ```

        :param str resource_name: The name of the resource.
        :param pulumi.ResourceOptions opts: Options for the resource.
        :param pulumi.Input[builtins.str] project_id: The id of the public cloud project. If omitted, the `OVH_CLOUD_PROJECT_SERVICE` environment variable is used.
        :param pulumi.Input[builtins.str] service_name: The service name of the vrack. If omitted, the `OVH_VRACK_SERVICE` environment variable is used.
        """
        ...
    @overload
    def __init__(__self__,
                 resource_name: str,
                 args: Optional[CloudProjectArgs] = None,
                 opts: Optional[pulumi.ResourceOptions] = None):
        """
        Attach a Public Cloud Project to a VRack.

        ## Example Usage

        ```python
        import pulumi
        import pulumi_ovh as ovh

        vcp = ovh.vrack.CloudProject("vcp",
            service_name="12345",
            project_id="67890")
        ```

        ## Import

        Attachment of a public cloud project and a VRack can be imported using the `service_name` (vRack identifier) and the `project_id` (Cloud Project identifier), separated by "/" E.g.,

        bash

        ```sh
        $ pulumi import ovh:Vrack/cloudProject:CloudProject myattach service_name/project_id
        ```

        :param str resource_name: The name of the resource.
        :param CloudProjectArgs args: The arguments to use to populate this resource's properties.
        :param pulumi.ResourceOptions opts: Options for the resource.
        """
        ...
    def __init__(__self__, resource_name: str, *args, **kwargs):
        resource_args, opts = _utilities.get_resource_args_opts(CloudProjectArgs, pulumi.ResourceOptions, *args, **kwargs)
        if resource_args is not None:
            __self__._internal_init(resource_name, opts, **resource_args.__dict__)
        else:
            __self__._internal_init(resource_name, *args, **kwargs)

    def _internal_init(__self__,
                 resource_name: str,
                 opts: Optional[pulumi.ResourceOptions] = None,
                 project_id: Optional[pulumi.Input[builtins.str]] = None,
                 service_name: Optional[pulumi.Input[builtins.str]] = None,
                 __props__=None):
        opts = pulumi.ResourceOptions.merge(_utilities.get_resource_opts_defaults(), opts)
        if not isinstance(opts, pulumi.ResourceOptions):
            raise TypeError('Expected resource options to be a ResourceOptions instance')
        if opts.id is None:
            if __props__ is not None:
                raise TypeError('__props__ is only valid when passed in combination with a valid opts.id to get an existing resource')
            __props__ = CloudProjectArgs.__new__(CloudProjectArgs)

            __props__.__dict__["project_id"] = project_id
            __props__.__dict__["service_name"] = service_name
        super(CloudProject, __self__).__init__(
            'ovh:Vrack/cloudProject:CloudProject',
            resource_name,
            __props__,
            opts)

    @staticmethod
    def get(resource_name: str,
            id: pulumi.Input[str],
            opts: Optional[pulumi.ResourceOptions] = None,
            project_id: Optional[pulumi.Input[builtins.str]] = None,
            service_name: Optional[pulumi.Input[builtins.str]] = None) -> 'CloudProject':
        """
        Get an existing CloudProject resource's state with the given name, id, and optional extra
        properties used to qualify the lookup.

        :param str resource_name: The unique name of the resulting resource.
        :param pulumi.Input[str] id: The unique provider ID of the resource to lookup.
        :param pulumi.ResourceOptions opts: Options for the resource.
        :param pulumi.Input[builtins.str] project_id: The id of the public cloud project. If omitted, the `OVH_CLOUD_PROJECT_SERVICE` environment variable is used.
        :param pulumi.Input[builtins.str] service_name: The service name of the vrack. If omitted, the `OVH_VRACK_SERVICE` environment variable is used.
        """
        opts = pulumi.ResourceOptions.merge(opts, pulumi.ResourceOptions(id=id))

        __props__ = _CloudProjectState.__new__(_CloudProjectState)

        __props__.__dict__["project_id"] = project_id
        __props__.__dict__["service_name"] = service_name
        return CloudProject(resource_name, opts=opts, __props__=__props__)

    @property
    @pulumi.getter(name="projectId")
    def project_id(self) -> pulumi.Output[builtins.str]:
        """
        The id of the public cloud project. If omitted, the `OVH_CLOUD_PROJECT_SERVICE` environment variable is used.
        """
        return pulumi.get(self, "project_id")

    @property
    @pulumi.getter(name="serviceName")
    def service_name(self) -> pulumi.Output[builtins.str]:
        """
        The service name of the vrack. If omitted, the `OVH_VRACK_SERVICE` environment variable is used.
        """
        return pulumi.get(self, "service_name")




# coding=utf-8
# *** WARNING: this file was generated by pulumi-language-python. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import builtins
import copy
import warnings
import sys
import pulumi
import pulumi.runtime
from typing import Any, Mapping, Optional, Sequence, Union, overload
if sys.version_info >= (3, 11):
    from typing import NotRequired, TypedDict, TypeAlias
else:
    from typing_extensions import NotRequired, TypedDict, TypeAlias
from .. import _utilities

__all__ = [
    'GetFirewallRuleResult',
    'AwaitableGetFirewallRuleResult',
    'get_firewall_rule',
    'get_firewall_rule_output',
]

@pulumi.output_type
class GetFirewallRuleResult:
    """
    A collection of values returned by getFirewallRule.
    """
    def __init__(__self__, action=None, creation_date=None, destination=None, destination_port=None, fragments=None, id=None, ip=None, ip_on_firewall=None, protocol=None, rule=None, sequence=None, source=None, source_port=None, state=None, tcp_option=None):
        if action and not isinstance(action, str):
            raise TypeError("Expected argument 'action' to be a str")
        pulumi.set(__self__, "action", action)
        if creation_date and not isinstance(creation_date, str):
            raise TypeError("Expected argument 'creation_date' to be a str")
        pulumi.set(__self__, "creation_date", creation_date)
        if destination and not isinstance(destination, str):
            raise TypeError("Expected argument 'destination' to be a str")
        pulumi.set(__self__, "destination", destination)
        if destination_port and not isinstance(destination_port, str):
            raise TypeError("Expected argument 'destination_port' to be a str")
        pulumi.set(__self__, "destination_port", destination_port)
        if fragments and not isinstance(fragments, bool):
            raise TypeError("Expected argument 'fragments' to be a bool")
        pulumi.set(__self__, "fragments", fragments)
        if id and not isinstance(id, str):
            raise TypeError("Expected argument 'id' to be a str")
        pulumi.set(__self__, "id", id)
        if ip and not isinstance(ip, str):
            raise TypeError("Expected argument 'ip' to be a str")
        pulumi.set(__self__, "ip", ip)
        if ip_on_firewall and not isinstance(ip_on_firewall, str):
            raise TypeError("Expected argument 'ip_on_firewall' to be a str")
        pulumi.set(__self__, "ip_on_firewall", ip_on_firewall)
        if protocol and not isinstance(protocol, str):
            raise TypeError("Expected argument 'protocol' to be a str")
        pulumi.set(__self__, "protocol", protocol)
        if rule and not isinstance(rule, str):
            raise TypeError("Expected argument 'rule' to be a str")
        pulumi.set(__self__, "rule", rule)
        if sequence and not isinstance(sequence, float):
            raise TypeError("Expected argument 'sequence' to be a float")
        pulumi.set(__self__, "sequence", sequence)
        if source and not isinstance(source, str):
            raise TypeError("Expected argument 'source' to be a str")
        pulumi.set(__self__, "source", source)
        if source_port and not isinstance(source_port, str):
            raise TypeError("Expected argument 'source_port' to be a str")
        pulumi.set(__self__, "source_port", source_port)
        if state and not isinstance(state, str):
            raise TypeError("Expected argument 'state' to be a str")
        pulumi.set(__self__, "state", state)
        if tcp_option and not isinstance(tcp_option, str):
            raise TypeError("Expected argument 'tcp_option' to be a str")
        pulumi.set(__self__, "tcp_option", tcp_option)

    @property
    @pulumi.getter
    def action(self) -> builtins.str:
        """
        Possible values for action (deny|permit)
        """
        return pulumi.get(self, "action")

    @property
    @pulumi.getter(name="creationDate")
    def creation_date(self) -> builtins.str:
        """
        Creation date of the rule
        """
        return pulumi.get(self, "creation_date")

    @property
    @pulumi.getter
    def destination(self) -> builtins.str:
        """
        Destination IP for your rule
        """
        return pulumi.get(self, "destination")

    @property
    @pulumi.getter(name="destinationPort")
    def destination_port(self) -> builtins.str:
        """
        Destination port for your rule. Only with TCP/UDP protocol
        """
        return pulumi.get(self, "destination_port")

    @property
    @pulumi.getter
    def fragments(self) -> builtins.bool:
        """
        Fragments option
        """
        return pulumi.get(self, "fragments")

    @property
    @pulumi.getter
    def id(self) -> builtins.str:
        """
        The provider-assigned unique ID for this managed resource.
        """
        return pulumi.get(self, "id")

    @property
    @pulumi.getter
    def ip(self) -> builtins.str:
        """
        The IP or the CIDR
        """
        return pulumi.get(self, "ip")

    @property
    @pulumi.getter(name="ipOnFirewall")
    def ip_on_firewall(self) -> builtins.str:
        """
        IPv4 address
        """
        return pulumi.get(self, "ip_on_firewall")

    @property
    @pulumi.getter
    def protocol(self) -> builtins.str:
        """
        Possible values for protocol (ah|esp|gre|icmp|ipv4|tcp|udp)
        """
        return pulumi.get(self, "protocol")

    @property
    @pulumi.getter
    def rule(self) -> builtins.str:
        """
        Description of the rule
        """
        return pulumi.get(self, "rule")

    @property
    @pulumi.getter
    def sequence(self) -> builtins.float:
        """
        Rule position in the rules array
        """
        return pulumi.get(self, "sequence")

    @property
    @pulumi.getter
    def source(self) -> builtins.str:
        """
        IPv4 CIDR notation (e.g., 192.0.2.0/24)
        """
        return pulumi.get(self, "source")

    @property
    @pulumi.getter(name="sourcePort")
    def source_port(self) -> builtins.str:
        """
        Source port for your rule. Only with TCP/UDP protocol
        """
        return pulumi.get(self, "source_port")

    @property
    @pulumi.getter
    def state(self) -> builtins.str:
        """
        Current state of your rule
        """
        return pulumi.get(self, "state")

    @property
    @pulumi.getter(name="tcpOption")
    def tcp_option(self) -> builtins.str:
        """
        TCP option on your rule (syn|established)
        """
        return pulumi.get(self, "tcp_option")


class AwaitableGetFirewallRuleResult(GetFirewallRuleResult):
    # pylint: disable=using-constant-test
    def __await__(self):
        if False:
            yield self
        return GetFirewallRuleResult(
            action=self.action,
            creation_date=self.creation_date,
            destination=self.destination,
            destination_port=self.destination_port,
            fragments=self.fragments,
            id=self.id,
            ip=self.ip,
            ip_on_firewall=self.ip_on_firewall,
            protocol=self.protocol,
            rule=self.rule,
            sequence=self.sequence,
            source=self.source,
            source_port=self.source_port,
            state=self.state,
            tcp_option=self.tcp_option)


def get_firewall_rule(ip: Optional[builtins.str] = None,
                      ip_on_firewall: Optional[builtins.str] = None,
                      sequence: Optional[builtins.float] = None,
                      opts: Optional[pulumi.InvokeOptions] = None) -> AwaitableGetFirewallRuleResult:
    """
    Use this data source to retrieve information about a rule on an IP firewall.

    ## Example Usage

    ```python
    import pulumi
    import pulumi_ovh as ovh

    my_firewall_rule = ovh.Ip.get_firewall_rule(ip="XXXXXX",
        ip_on_firewall="XXXXXX",
        sequence=0)
    ```


    :param builtins.str ip: The IP or the CIDR
    :param builtins.str ip_on_firewall: IPv4 address
    :param builtins.float sequence: Rule position in the rules array
    """
    __args__ = dict()
    __args__['ip'] = ip
    __args__['ipOnFirewall'] = ip_on_firewall
    __args__['sequence'] = sequence
    opts = pulumi.InvokeOptions.merge(_utilities.get_invoke_opts_defaults(), opts)
    __ret__ = pulumi.runtime.invoke('ovh:Ip/getFirewallRule:getFirewallRule', __args__, opts=opts, typ=GetFirewallRuleResult).value

    return AwaitableGetFirewallRuleResult(
        action=pulumi.get(__ret__, 'action'),
        creation_date=pulumi.get(__ret__, 'creation_date'),
        destination=pulumi.get(__ret__, 'destination'),
        destination_port=pulumi.get(__ret__, 'destination_port'),
        fragments=pulumi.get(__ret__, 'fragments'),
        id=pulumi.get(__ret__, 'id'),
        ip=pulumi.get(__ret__, 'ip'),
        ip_on_firewall=pulumi.get(__ret__, 'ip_on_firewall'),
        protocol=pulumi.get(__ret__, 'protocol'),
        rule=pulumi.get(__ret__, 'rule'),
        sequence=pulumi.get(__ret__, 'sequence'),
        source=pulumi.get(__ret__, 'source'),
        source_port=pulumi.get(__ret__, 'source_port'),
        state=pulumi.get(__ret__, 'state'),
        tcp_option=pulumi.get(__ret__, 'tcp_option'))
def get_firewall_rule_output(ip: Optional[pulumi.Input[builtins.str]] = None,
                             ip_on_firewall: Optional[pulumi.Input[builtins.str]] = None,
                             sequence: Optional[pulumi.Input[builtins.float]] = None,
                             opts: Optional[Union[pulumi.InvokeOptions, pulumi.InvokeOutputOptions]] = None) -> pulumi.Output[GetFirewallRuleResult]:
    """
    Use this data source to retrieve information about a rule on an IP firewall.

    ## Example Usage

    ```python
    import pulumi
    import pulumi_ovh as ovh

    my_firewall_rule = ovh.Ip.get_firewall_rule(ip="XXXXXX",
        ip_on_firewall="XXXXXX",
        sequence=0)
    ```


    :param builtins.str ip: The IP or the CIDR
    :param builtins.str ip_on_firewall: IPv4 address
    :param builtins.float sequence: Rule position in the rules array
    """
    __args__ = dict()
    __args__['ip'] = ip
    __args__['ipOnFirewall'] = ip_on_firewall
    __args__['sequence'] = sequence
    opts = pulumi.InvokeOutputOptions.merge(_utilities.get_invoke_opts_defaults(), opts)
    __ret__ = pulumi.runtime.invoke_output('ovh:Ip/getFirewallRule:getFirewallRule', __args__, opts=opts, typ=GetFirewallRuleResult)
    return __ret__.apply(lambda __response__: GetFirewallRuleResult(
        action=pulumi.get(__response__, 'action'),
        creation_date=pulumi.get(__response__, 'creation_date'),
        destination=pulumi.get(__response__, 'destination'),
        destination_port=pulumi.get(__response__, 'destination_port'),
        fragments=pulumi.get(__response__, 'fragments'),
        id=pulumi.get(__response__, 'id'),
        ip=pulumi.get(__response__, 'ip'),
        ip_on_firewall=pulumi.get(__response__, 'ip_on_firewall'),
        protocol=pulumi.get(__response__, 'protocol'),
        rule=pulumi.get(__response__, 'rule'),
        sequence=pulumi.get(__response__, 'sequence'),
        source=pulumi.get(__response__, 'source'),
        source_port=pulumi.get(__response__, 'source_port'),
        state=pulumi.get(__response__, 'state'),
        tcp_option=pulumi.get(__response__, 'tcp_option')))



# coding=utf-8
# *** WARNING: this file was generated by pulumi-language-python. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import builtins
import copy
import warnings
import sys
import pulumi
import pulumi.runtime
from typing import Any, Mapping, Optional, Sequence, Union, overload
if sys.version_info >= (3, 11):
    from typing import NotRequired, TypedDict, TypeAlias
else:
    from typing_extensions import NotRequired, TypedDict, TypeAlias
from .. import _utilities

__all__ = [
    'GetImageResult',
    'AwaitableGetImageResult',
    'get_image',
    'get_image_output',
]

@pulumi.output_type
class GetImageResult:
    """
    A collection of values returned by getImage.
    """
    def __init__(__self__, creation_date=None, flavor_type=None, id=None, image_id=None, min_disk=None, min_ram=None, name=None, plan_code=None, region=None, service_name=None, size=None, status=None, tags=None, type=None, user=None, visibility=None):
        if creation_date and not isinstance(creation_date, str):
            raise TypeError("Expected argument 'creation_date' to be a str")
        pulumi.set(__self__, "creation_date", creation_date)
        if flavor_type and not isinstance(flavor_type, str):
            raise TypeError("Expected argument 'flavor_type' to be a str")
        pulumi.set(__self__, "flavor_type", flavor_type)
        if id and not isinstance(id, str):
            raise TypeError("Expected argument 'id' to be a str")
        pulumi.set(__self__, "id", id)
        if image_id and not isinstance(image_id, str):
            raise TypeError("Expected argument 'image_id' to be a str")
        pulumi.set(__self__, "image_id", image_id)
        if min_disk and not isinstance(min_disk, float):
            raise TypeError("Expected argument 'min_disk' to be a float")
        pulumi.set(__self__, "min_disk", min_disk)
        if min_ram and not isinstance(min_ram, float):
            raise TypeError("Expected argument 'min_ram' to be a float")
        pulumi.set(__self__, "min_ram", min_ram)
        if name and not isinstance(name, str):
            raise TypeError("Expected argument 'name' to be a str")
        pulumi.set(__self__, "name", name)
        if plan_code and not isinstance(plan_code, str):
            raise TypeError("Expected argument 'plan_code' to be a str")
        pulumi.set(__self__, "plan_code", plan_code)
        if region and not isinstance(region, str):
            raise TypeError("Expected argument 'region' to be a str")
        pulumi.set(__self__, "region", region)
        if service_name and not isinstance(service_name, str):
            raise TypeError("Expected argument 'service_name' to be a str")
        pulumi.set(__self__, "service_name", service_name)
        if size and not isinstance(size, float):
            raise TypeError("Expected argument 'size' to be a float")
        pulumi.set(__self__, "size", size)
        if status and not isinstance(status, str):
            raise TypeError("Expected argument 'status' to be a str")
        pulumi.set(__self__, "status", status)
        if tags and not isinstance(tags, list):
            raise TypeError("Expected argument 'tags' to be a list")
        pulumi.set(__self__, "tags", tags)
        if type and not isinstance(type, str):
            raise TypeError("Expected argument 'type' to be a str")
        pulumi.set(__self__, "type", type)
        if user and not isinstance(user, str):
            raise TypeError("Expected argument 'user' to be a str")
        pulumi.set(__self__, "user", user)
        if visibility and not isinstance(visibility, str):
            raise TypeError("Expected argument 'visibility' to be a str")
        pulumi.set(__self__, "visibility", visibility)

    @property
    @pulumi.getter(name="creationDate")
    def creation_date(self) -> builtins.str:
        """
        Image creation date
        """
        return pulumi.get(self, "creation_date")

    @property
    @pulumi.getter(name="flavorType")
    def flavor_type(self) -> builtins.str:
        """
        Image usable only for this type of flavor if not null
        """
        return pulumi.get(self, "flavor_type")

    @property
    @pulumi.getter
    def id(self) -> builtins.str:
        """
        Image ID
        """
        return pulumi.get(self, "id")

    @property
    @pulumi.getter(name="imageId")
    def image_id(self) -> builtins.str:
        """
        Image ID
        """
        return pulumi.get(self, "image_id")

    @property
    @pulumi.getter(name="minDisk")
    def min_disk(self) -> builtins.float:
        """
        Minimum disks required to use image
        """
        return pulumi.get(self, "min_disk")

    @property
    @pulumi.getter(name="minRam")
    def min_ram(self) -> builtins.float:
        """
        Minimum RAM required to use image
        """
        return pulumi.get(self, "min_ram")

    @property
    @pulumi.getter
    def name(self) -> builtins.str:
        """
        Image name
        """
        return pulumi.get(self, "name")

    @property
    @pulumi.getter(name="planCode")
    def plan_code(self) -> builtins.str:
        """
        Order plan code
        """
        return pulumi.get(self, "plan_code")

    @property
    @pulumi.getter
    def region(self) -> builtins.str:
        """
        Image region
        """
        return pulumi.get(self, "region")

    @property
    @pulumi.getter(name="serviceName")
    def service_name(self) -> builtins.str:
        """
        Public cloud project ID
        """
        return pulumi.get(self, "service_name")

    @property
    @pulumi.getter
    def size(self) -> builtins.float:
        """
        Image size (in GiB)
        """
        return pulumi.get(self, "size")

    @property
    @pulumi.getter
    def status(self) -> builtins.str:
        """
        Image status
        """
        return pulumi.get(self, "status")

    @property
    @pulumi.getter
    def tags(self) -> Sequence[builtins.str]:
        """
        Tags about the image
        """
        return pulumi.get(self, "tags")

    @property
    @pulumi.getter
    def type(self) -> builtins.str:
        """
        Image type
        """
        return pulumi.get(self, "type")

    @property
    @pulumi.getter
    def user(self) -> builtins.str:
        """
        User to connect with
        """
        return pulumi.get(self, "user")

    @property
    @pulumi.getter
    def visibility(self) -> builtins.str:
        """
        Image visibility
        """
        return pulumi.get(self, "visibility")


class AwaitableGetImageResult(GetImageResult):
    # pylint: disable=using-constant-test
    def __await__(self):
        if False:
            yield self
        return GetImageResult(
            creation_date=self.creation_date,
            flavor_type=self.flavor_type,
            id=self.id,
            image_id=self.image_id,
            min_disk=self.min_disk,
            min_ram=self.min_ram,
            name=self.name,
            plan_code=self.plan_code,
            region=self.region,
            service_name=self.service_name,
            size=self.size,
            status=self.status,
            tags=self.tags,
            type=self.type,
            user=self.user,
            visibility=self.visibility)


def get_image(image_id: Optional[builtins.str] = None,
              service_name: Optional[builtins.str] = None,
              opts: Optional[pulumi.InvokeOptions] = None) -> AwaitableGetImageResult:
    """
    Get information about an image in the given public cloud project.

    ## Example Usage

    ```python
    import pulumi
    import pulumi_ovh as ovh

    image = ovh.CloudProject.get_image(service_name="<public cloud project ID>",
        image_id="<image ID>")
    ```


    :param builtins.str image_id: Image ID
    :param builtins.str service_name: Public cloud project ID
    """
    __args__ = dict()
    __args__['imageId'] = image_id
    __args__['serviceName'] = service_name
    opts = pulumi.InvokeOptions.merge(_utilities.get_invoke_opts_defaults(), opts)
    __ret__ = pulumi.runtime.invoke('ovh:CloudProject/getImage:getImage', __args__, opts=opts, typ=GetImageResult).value

    return AwaitableGetImageResult(
        creation_date=pulumi.get(__ret__, 'creation_date'),
        flavor_type=pulumi.get(__ret__, 'flavor_type'),
        id=pulumi.get(__ret__, 'id'),
        image_id=pulumi.get(__ret__, 'image_id'),
        min_disk=pulumi.get(__ret__, 'min_disk'),
        min_ram=pulumi.get(__ret__, 'min_ram'),
        name=pulumi.get(__ret__, 'name'),
        plan_code=pulumi.get(__ret__, 'plan_code'),
        region=pulumi.get(__ret__, 'region'),
        service_name=pulumi.get(__ret__, 'service_name'),
        size=pulumi.get(__ret__, 'size'),
        status=pulumi.get(__ret__, 'status'),
        tags=pulumi.get(__ret__, 'tags'),
        type=pulumi.get(__ret__, 'type'),
        user=pulumi.get(__ret__, 'user'),
        visibility=pulumi.get(__ret__, 'visibility'))
def get_image_output(image_id: Optional[pulumi.Input[builtins.str]] = None,
                     service_name: Optional[pulumi.Input[builtins.str]] = None,
                     opts: Optional[Union[pulumi.InvokeOptions, pulumi.InvokeOutputOptions]] = None) -> pulumi.Output[GetImageResult]:
    """
    Get information about an image in the given public cloud project.

    ## Example Usage

    ```python
    import pulumi
    import pulumi_ovh as ovh

    image = ovh.CloudProject.get_image(service_name="<public cloud project ID>",
        image_id="<image ID>")
    ```


    :param builtins.str image_id: Image ID
    :param builtins.str service_name: Public cloud project ID
    """
    __args__ = dict()
    __args__['imageId'] = image_id
    __args__['serviceName'] = service_name
    opts = pulumi.InvokeOutputOptions.merge(_utilities.get_invoke_opts_defaults(), opts)
    __ret__ = pulumi.runtime.invoke_output('ovh:CloudProject/getImage:getImage', __args__, opts=opts, typ=GetImageResult)
    return __ret__.apply(lambda __response__: GetImageResult(
        creation_date=pulumi.get(__response__, 'creation_date'),
        flavor_type=pulumi.get(__response__, 'flavor_type'),
        id=pulumi.get(__response__, 'id'),
        image_id=pulumi.get(__response__, 'image_id'),
        min_disk=pulumi.get(__response__, 'min_disk'),
        min_ram=pulumi.get(__response__, 'min_ram'),
        name=pulumi.get(__response__, 'name'),
        plan_code=pulumi.get(__response__, 'plan_code'),
        region=pulumi.get(__response__, 'region'),
        service_name=pulumi.get(__response__, 'service_name'),
        size=pulumi.get(__response__, 'size'),
        status=pulumi.get(__response__, 'status'),
        tags=pulumi.get(__response__, 'tags'),
        type=pulumi.get(__response__, 'type'),
        user=pulumi.get(__response__, 'user'),
        visibility=pulumi.get(__response__, 'visibility')))



# coding=utf-8
# *** WARNING: this file was generated by pulumi-language-python. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import builtins
import copy
import warnings
import sys
import pulumi
import pulumi.runtime
from typing import Any, Mapping, Optional, Sequence, Union, overload
if sys.version_info >= (3, 11):
    from typing import NotRequired, TypedDict, TypeAlias
else:
    from typing_extensions import NotRequired, TypedDict, TypeAlias
from .. import _utilities
from . import outputs

__all__ = [
    'GetReferenceActionsResult',
    'AwaitableGetReferenceActionsResult',
    'get_reference_actions',
    'get_reference_actions_output',
]

@pulumi.output_type
class GetReferenceActionsResult:
    """
    A collection of values returned by getReferenceActions.
    """
    def __init__(__self__, actions=None, id=None, type=None):
        if actions and not isinstance(actions, list):
            raise TypeError("Expected argument 'actions' to be a list")
        pulumi.set(__self__, "actions", actions)
        if id and not isinstance(id, str):
            raise TypeError("Expected argument 'id' to be a str")
        pulumi.set(__self__, "id", id)
        if type and not isinstance(type, str):
            raise TypeError("Expected argument 'type' to be a str")
        pulumi.set(__self__, "type", type)

    @property
    @pulumi.getter
    def actions(self) -> Sequence['outputs.GetReferenceActionsActionResult']:
        """
        List of actions
        """
        return pulumi.get(self, "actions")

    @property
    @pulumi.getter
    def id(self) -> builtins.str:
        """
        The provider-assigned unique ID for this managed resource.
        """
        return pulumi.get(self, "id")

    @property
    @pulumi.getter
    def type(self) -> builtins.str:
        return pulumi.get(self, "type")


class AwaitableGetReferenceActionsResult(GetReferenceActionsResult):
    # pylint: disable=using-constant-test
    def __await__(self):
        if False:
            yield self
        return GetReferenceActionsResult(
            actions=self.actions,
            id=self.id,
            type=self.type)


def get_reference_actions(type: Optional[builtins.str] = None,
                          opts: Optional[pulumi.InvokeOptions] = None) -> AwaitableGetReferenceActionsResult:
    """
    Use this data source to list the IAM action associated with a resource type.


    :param builtins.str type: Kind of resource we want the actions for
    """
    __args__ = dict()
    __args__['type'] = type
    opts = pulumi.InvokeOptions.merge(_utilities.get_invoke_opts_defaults(), opts)
    __ret__ = pulumi.runtime.invoke('ovh:Iam/getReferenceActions:getReferenceActions', __args__, opts=opts, typ=GetReferenceActionsResult).value

    return AwaitableGetReferenceActionsResult(
        actions=pulumi.get(__ret__, 'actions'),
        id=pulumi.get(__ret__, 'id'),
        type=pulumi.get(__ret__, 'type'))
def get_reference_actions_output(type: Optional[pulumi.Input[builtins.str]] = None,
                                 opts: Optional[Union[pulumi.InvokeOptions, pulumi.InvokeOutputOptions]] = None) -> pulumi.Output[GetReferenceActionsResult]:
    """
    Use this data source to list the IAM action associated with a resource type.


    :param builtins.str type: Kind of resource we want the actions for
    """
    __args__ = dict()
    __args__['type'] = type
    opts = pulumi.InvokeOutputOptions.merge(_utilities.get_invoke_opts_defaults(), opts)
    __ret__ = pulumi.runtime.invoke_output('ovh:Iam/getReferenceActions:getReferenceActions', __args__, opts=opts, typ=GetReferenceActionsResult)
    return __ret__.apply(lambda __response__: GetReferenceActionsResult(
        actions=pulumi.get(__response__, 'actions'),
        id=pulumi.get(__response__, 'id'),
        type=pulumi.get(__response__, 'type')))



# coding=utf-8
# *** WARNING: this file was generated by pulumi-language-python. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import builtins
import copy
import warnings
import sys
import pulumi
import pulumi.runtime
from typing import Any, Mapping, Optional, Sequence, Union, overload
if sys.version_info >= (3, 11):
    from typing import NotRequired, TypedDict, TypeAlias
else:
    from typing_extensions import NotRequired, TypedDict, TypeAlias
from .. import _utilities

__all__ = ['S3CredentialArgs', 'S3Credential']

@pulumi.input_type
class S3CredentialArgs:
    def __init__(__self__, *,
                 user_id: pulumi.Input[builtins.str],
                 service_name: Optional[pulumi.Input[builtins.str]] = None):
        """
        The set of arguments for constructing a S3Credential resource.
        :param pulumi.Input[builtins.str] user_id: The ID of a public cloud project's user.
        :param pulumi.Input[builtins.str] service_name: The ID of the public cloud project. If omitted, the `OVH_CLOUD_PROJECT_SERVICE` environment variable is used.
        """
        pulumi.set(__self__, "user_id", user_id)
        if service_name is not None:
            pulumi.set(__self__, "service_name", service_name)

    @property
    @pulumi.getter(name="userId")
    def user_id(self) -> pulumi.Input[builtins.str]:
        """
        The ID of a public cloud project's user.
        """
        return pulumi.get(self, "user_id")

    @user_id.setter
    def user_id(self, value: pulumi.Input[builtins.str]):
        pulumi.set(self, "user_id", value)

    @property
    @pulumi.getter(name="serviceName")
    def service_name(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        The ID of the public cloud project. If omitted, the `OVH_CLOUD_PROJECT_SERVICE` environment variable is used.
        """
        return pulumi.get(self, "service_name")

    @service_name.setter
    def service_name(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "service_name", value)


@pulumi.input_type
class _S3CredentialState:
    def __init__(__self__, *,
                 access_key_id: Optional[pulumi.Input[builtins.str]] = None,
                 internal_user_id: Optional[pulumi.Input[builtins.str]] = None,
                 secret_access_key: Optional[pulumi.Input[builtins.str]] = None,
                 service_name: Optional[pulumi.Input[builtins.str]] = None,
                 user_id: Optional[pulumi.Input[builtins.str]] = None):
        """
        Input properties used for looking up and filtering S3Credential resources.
        :param pulumi.Input[builtins.str] access_key_id: the Access Key ID
        :param pulumi.Input[builtins.str] secret_access_key: (Sensitive) the Secret Access Key
        :param pulumi.Input[builtins.str] service_name: The ID of the public cloud project. If omitted, the `OVH_CLOUD_PROJECT_SERVICE` environment variable is used.
        :param pulumi.Input[builtins.str] user_id: The ID of a public cloud project's user.
        """
        if access_key_id is not None:
            pulumi.set(__self__, "access_key_id", access_key_id)
        if internal_user_id is not None:
            pulumi.set(__self__, "internal_user_id", internal_user_id)
        if secret_access_key is not None:
            pulumi.set(__self__, "secret_access_key", secret_access_key)
        if service_name is not None:
            pulumi.set(__self__, "service_name", service_name)
        if user_id is not None:
            pulumi.set(__self__, "user_id", user_id)

    @property
    @pulumi.getter(name="accessKeyId")
    def access_key_id(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        the Access Key ID
        """
        return pulumi.get(self, "access_key_id")

    @access_key_id.setter
    def access_key_id(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "access_key_id", value)

    @property
    @pulumi.getter(name="internalUserId")
    def internal_user_id(self) -> Optional[pulumi.Input[builtins.str]]:
        return pulumi.get(self, "internal_user_id")

    @internal_user_id.setter
    def internal_user_id(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "internal_user_id", value)

    @property
    @pulumi.getter(name="secretAccessKey")
    def secret_access_key(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        (Sensitive) the Secret Access Key
        """
        return pulumi.get(self, "secret_access_key")

    @secret_access_key.setter
    def secret_access_key(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "secret_access_key", value)

    @property
    @pulumi.getter(name="serviceName")
    def service_name(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        The ID of the public cloud project. If omitted, the `OVH_CLOUD_PROJECT_SERVICE` environment variable is used.
        """
        return pulumi.get(self, "service_name")

    @service_name.setter
    def service_name(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "service_name", value)

    @property
    @pulumi.getter(name="userId")
    def user_id(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        The ID of a public cloud project's user.
        """
        return pulumi.get(self, "user_id")

    @user_id.setter
    def user_id(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "user_id", value)


@pulumi.type_token("ovh:CloudProject/s3Credential:S3Credential")
class S3Credential(pulumi.CustomResource):
    @overload
    def __init__(__self__,
                 resource_name: str,
                 opts: Optional[pulumi.ResourceOptions] = None,
                 service_name: Optional[pulumi.Input[builtins.str]] = None,
                 user_id: Optional[pulumi.Input[builtins.str]] = None,
                 __props__=None):
        """
        Creates an S3 Credential for a user in a public cloud project.

        ## Example Usage

        ```python
        import pulumi
        import pulumi_ovh as ovh

        user = ovh.cloud_project.User("user",
            service_name="XXX",
            description="my user for acceptance tests",
            role_names=["objectstore_operator"])
        my_s3_credentials = ovh.cloud_project.S3Credential("my_s3_credentials",
            service_name=user.service_name,
            user_id=user.id)
        ```

        ## Import

        OVHcloud User S3 Credentials can be imported using the `service_name`, `user_id` and `access_key_id` of the credential, separated by "/" E.g.,

        bash

        ```sh
        $ pulumi import ovh:CloudProject/s3Credential:S3Credential s3_credential service_name/user_id/access_key_id
        ```

        :param str resource_name: The name of the resource.
        :param pulumi.ResourceOptions opts: Options for the resource.
        :param pulumi.Input[builtins.str] service_name: The ID of the public cloud project. If omitted, the `OVH_CLOUD_PROJECT_SERVICE` environment variable is used.
        :param pulumi.Input[builtins.str] user_id: The ID of a public cloud project's user.
        """
        ...
    @overload
    def __init__(__self__,
                 resource_name: str,
                 args: S3CredentialArgs,
                 opts: Optional[pulumi.ResourceOptions] = None):
        """
        Creates an S3 Credential for a user in a public cloud project.

        ## Example Usage

        ```python
        import pulumi
        import pulumi_ovh as ovh

        user = ovh.cloud_project.User("user",
            service_name="XXX",
            description="my user for acceptance tests",
            role_names=["objectstore_operator"])
        my_s3_credentials = ovh.cloud_project.S3Credential("my_s3_credentials",
            service_name=user.service_name,
            user_id=user.id)
        ```

        ## Import

        OVHcloud User S3 Credentials can be imported using the `service_name`, `user_id` and `access_key_id` of the credential, separated by "/" E.g.,

        bash

        ```sh
        $ pulumi import ovh:CloudProject/s3Credential:S3Credential s3_credential service_name/user_id/access_key_id
        ```

        :param str resource_name: The name of the resource.
        :param S3CredentialArgs args: The arguments to use to populate this resource's properties.
        :param pulumi.ResourceOptions opts: Options for the resource.
        """
        ...
    def __init__(__self__, resource_name: str, *args, **kwargs):
        resource_args, opts = _utilities.get_resource_args_opts(S3CredentialArgs, pulumi.ResourceOptions, *args, **kwargs)
        if resource_args is not None:
            __self__._internal_init(resource_name, opts, **resource_args.__dict__)
        else:
            __self__._internal_init(resource_name, *args, **kwargs)

    def _internal_init(__self__,
                 resource_name: str,
                 opts: Optional[pulumi.ResourceOptions] = None,
                 service_name: Optional[pulumi.Input[builtins.str]] = None,
                 user_id: Optional[pulumi.Input[builtins.str]] = None,
                 __props__=None):
        opts = pulumi.ResourceOptions.merge(_utilities.get_resource_opts_defaults(), opts)
        if not isinstance(opts, pulumi.ResourceOptions):
            raise TypeError('Expected resource options to be a ResourceOptions instance')
        if opts.id is None:
            if __props__ is not None:
                raise TypeError('__props__ is only valid when passed in combination with a valid opts.id to get an existing resource')
            __props__ = S3CredentialArgs.__new__(S3CredentialArgs)

            __props__.__dict__["service_name"] = service_name
            if user_id is None and not opts.urn:
                raise TypeError("Missing required property 'user_id'")
            __props__.__dict__["user_id"] = user_id
            __props__.__dict__["access_key_id"] = None
            __props__.__dict__["internal_user_id"] = None
            __props__.__dict__["secret_access_key"] = None
        secret_opts = pulumi.ResourceOptions(additional_secret_outputs=["secretAccessKey"])
        opts = pulumi.ResourceOptions.merge(opts, secret_opts)
        super(S3Credential, __self__).__init__(
            'ovh:CloudProject/s3Credential:S3Credential',
            resource_name,
            __props__,
            opts)

    @staticmethod
    def get(resource_name: str,
            id: pulumi.Input[str],
            opts: Optional[pulumi.ResourceOptions] = None,
            access_key_id: Optional[pulumi.Input[builtins.str]] = None,
            internal_user_id: Optional[pulumi.Input[builtins.str]] = None,
            secret_access_key: Optional[pulumi.Input[builtins.str]] = None,
            service_name: Optional[pulumi.Input[builtins.str]] = None,
            user_id: Optional[pulumi.Input[builtins.str]] = None) -> 'S3Credential':
        """
        Get an existing S3Credential resource's state with the given name, id, and optional extra
        properties used to qualify the lookup.

        :param str resource_name: The unique name of the resulting resource.
        :param pulumi.Input[str] id: The unique provider ID of the resource to lookup.
        :param pulumi.ResourceOptions opts: Options for the resource.
        :param pulumi.Input[builtins.str] access_key_id: the Access Key ID
        :param pulumi.Input[builtins.str] secret_access_key: (Sensitive) the Secret Access Key
        :param pulumi.Input[builtins.str] service_name: The ID of the public cloud project. If omitted, the `OVH_CLOUD_PROJECT_SERVICE` environment variable is used.
        :param pulumi.Input[builtins.str] user_id: The ID of a public cloud project's user.
        """
        opts = pulumi.ResourceOptions.merge(opts, pulumi.ResourceOptions(id=id))

        __props__ = _S3CredentialState.__new__(_S3CredentialState)

        __props__.__dict__["access_key_id"] = access_key_id
        __props__.__dict__["internal_user_id"] = internal_user_id
        __props__.__dict__["secret_access_key"] = secret_access_key
        __props__.__dict__["service_name"] = service_name
        __props__.__dict__["user_id"] = user_id
        return S3Credential(resource_name, opts=opts, __props__=__props__)

    @property
    @pulumi.getter(name="accessKeyId")
    def access_key_id(self) -> pulumi.Output[builtins.str]:
        """
        the Access Key ID
        """
        return pulumi.get(self, "access_key_id")

    @property
    @pulumi.getter(name="internalUserId")
    def internal_user_id(self) -> pulumi.Output[builtins.str]:
        return pulumi.get(self, "internal_user_id")

    @property
    @pulumi.getter(name="secretAccessKey")
    def secret_access_key(self) -> pulumi.Output[builtins.str]:
        """
        (Sensitive) the Secret Access Key
        """
        return pulumi.get(self, "secret_access_key")

    @property
    @pulumi.getter(name="serviceName")
    def service_name(self) -> pulumi.Output[builtins.str]:
        """
        The ID of the public cloud project. If omitted, the `OVH_CLOUD_PROJECT_SERVICE` environment variable is used.
        """
        return pulumi.get(self, "service_name")

    @property
    @pulumi.getter(name="userId")
    def user_id(self) -> pulumi.Output[builtins.str]:
        """
        The ID of a public cloud project's user.
        """
        return pulumi.get(self, "user_id")




# coding=utf-8
# *** WARNING: this file was generated by pulumi-language-python. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import builtins
from .. import _utilities
import typing
# Export this package's modules as members:
from .database_instance import *
from .get_capabilities import *
from .get_certificates import *
from .get_database import *
from .get_database_instance import *
from .get_database_instances import *
from .get_database_integration import *
from .get_database_integrations import *
from .get_database_log_subscription import *
from .get_database_log_subscriptions import *
from .get_database_postgre_sql_connection_pools import *
from .get_databases import *
from .get_ip_restrictions import *
from .get_kafka_acl import *
from .get_kafka_acls import *
from .get_kafka_schema_registry_acl import *
from .get_kafka_schema_registry_acls import *
from .get_kafka_topic import *
from .get_kafka_topics import *
from .get_kafka_user_access import *
from .get_postgres_sql_connection_pool import *
from .get_postgres_sql_user import *
from .get_user import *
from .get_users import *
from .integration import *
from .ip_restriction import *
from .kafka_acl import *
from .kafka_schema_registry_acl import *
from .kafka_topic import *
from .log_subscription import *
from .m3_db_namespace import *
from .m3_db_user import *
from .mongo_db_prometheus import *
from .mongo_db_user import *
from .opensearch_pattern import *
from .opensearch_user import *
from .postgres_sql_connection_pool import *
from .postgres_sql_user import *
from .prometheus import *
from .redis_user import *
from .user import *
from ._inputs import *
from . import outputs



# coding=utf-8
# *** WARNING: this file was generated by pulumi-language-python. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import builtins
import copy
import warnings
import sys
import pulumi
import pulumi.runtime
from typing import Any, Mapping, Optional, Sequence, Union, overload
if sys.version_info >= (3, 11):
    from typing import NotRequired, TypedDict, TypeAlias
else:
    from typing_extensions import NotRequired, TypedDict, TypeAlias
from .. import _utilities

__all__ = [
    'GetIpRestrictionsResult',
    'AwaitableGetIpRestrictionsResult',
    'get_ip_restrictions',
    'get_ip_restrictions_output',
]

@pulumi.output_type
class GetIpRestrictionsResult:
    """
    A collection of values returned by getIpRestrictions.
    """
    def __init__(__self__, cluster_id=None, engine=None, id=None, ips=None, service_name=None):
        if cluster_id and not isinstance(cluster_id, str):
            raise TypeError("Expected argument 'cluster_id' to be a str")
        pulumi.set(__self__, "cluster_id", cluster_id)
        if engine and not isinstance(engine, str):
            raise TypeError("Expected argument 'engine' to be a str")
        pulumi.set(__self__, "engine", engine)
        if id and not isinstance(id, str):
            raise TypeError("Expected argument 'id' to be a str")
        pulumi.set(__self__, "id", id)
        if ips and not isinstance(ips, list):
            raise TypeError("Expected argument 'ips' to be a list")
        pulumi.set(__self__, "ips", ips)
        if service_name and not isinstance(service_name, str):
            raise TypeError("Expected argument 'service_name' to be a str")
        pulumi.set(__self__, "service_name", service_name)

    @property
    @pulumi.getter(name="clusterId")
    def cluster_id(self) -> builtins.str:
        """
        See Argument Reference above.
        """
        return pulumi.get(self, "cluster_id")

    @property
    @pulumi.getter
    def engine(self) -> builtins.str:
        """
        See Argument Reference above.
        """
        return pulumi.get(self, "engine")

    @property
    @pulumi.getter
    def id(self) -> builtins.str:
        """
        The provider-assigned unique ID for this managed resource.
        """
        return pulumi.get(self, "id")

    @property
    @pulumi.getter
    def ips(self) -> Sequence[builtins.str]:
        """
        The list of IP restriction of the database associated with the project.
        """
        return pulumi.get(self, "ips")

    @property
    @pulumi.getter(name="serviceName")
    def service_name(self) -> builtins.str:
        """
        See Argument Reference above.
        """
        return pulumi.get(self, "service_name")


class AwaitableGetIpRestrictionsResult(GetIpRestrictionsResult):
    # pylint: disable=using-constant-test
    def __await__(self):
        if False:
            yield self
        return GetIpRestrictionsResult(
            cluster_id=self.cluster_id,
            engine=self.engine,
            id=self.id,
            ips=self.ips,
            service_name=self.service_name)


def get_ip_restrictions(cluster_id: Optional[builtins.str] = None,
                        engine: Optional[builtins.str] = None,
                        service_name: Optional[builtins.str] = None,
                        opts: Optional[pulumi.InvokeOptions] = None) -> AwaitableGetIpRestrictionsResult:
    """
    Deprecated: Use ip_restrictions field in cloud_project_database datasource instead.

    Use this data source to get the list of IP restrictions associated with a public cloud project.

    ## Example Usage

    To get the list of IP restriction on a database cluster service:

    ```python
    import pulumi
    import pulumi_ovh as ovh

    ip_restrictions = ovh.CloudProjectDatabase.get_ip_restrictions(service_name="XXXXXX",
        engine="YYYY",
        cluster_id="ZZZZ")
    pulumi.export("ips", ip_restrictions.ips)
    ```


    :param builtins.str cluster_id: Cluster ID
    :param builtins.str engine: The engine of the database cluster you want to list IP restrictions. To get a full list of available engine visit: [public documentation](https://docs.ovh.com/gb/en/publiccloud/databases).
    :param builtins.str service_name: The id of the public cloud project. If omitted, the `OVH_CLOUD_PROJECT_SERVICE` environment variable is used.
    """
    __args__ = dict()
    __args__['clusterId'] = cluster_id
    __args__['engine'] = engine
    __args__['serviceName'] = service_name
    opts = pulumi.InvokeOptions.merge(_utilities.get_invoke_opts_defaults(), opts)
    __ret__ = pulumi.runtime.invoke('ovh:CloudProjectDatabase/getIpRestrictions:getIpRestrictions', __args__, opts=opts, typ=GetIpRestrictionsResult).value

    return AwaitableGetIpRestrictionsResult(
        cluster_id=pulumi.get(__ret__, 'cluster_id'),
        engine=pulumi.get(__ret__, 'engine'),
        id=pulumi.get(__ret__, 'id'),
        ips=pulumi.get(__ret__, 'ips'),
        service_name=pulumi.get(__ret__, 'service_name'))
def get_ip_restrictions_output(cluster_id: Optional[pulumi.Input[builtins.str]] = None,
                               engine: Optional[pulumi.Input[builtins.str]] = None,
                               service_name: Optional[pulumi.Input[builtins.str]] = None,
                               opts: Optional[Union[pulumi.InvokeOptions, pulumi.InvokeOutputOptions]] = None) -> pulumi.Output[GetIpRestrictionsResult]:
    """
    Deprecated: Use ip_restrictions field in cloud_project_database datasource instead.

    Use this data source to get the list of IP restrictions associated with a public cloud project.

    ## Example Usage

    To get the list of IP restriction on a database cluster service:

    ```python
    import pulumi
    import pulumi_ovh as ovh

    ip_restrictions = ovh.CloudProjectDatabase.get_ip_restrictions(service_name="XXXXXX",
        engine="YYYY",
        cluster_id="ZZZZ")
    pulumi.export("ips", ip_restrictions.ips)
    ```


    :param builtins.str cluster_id: Cluster ID
    :param builtins.str engine: The engine of the database cluster you want to list IP restrictions. To get a full list of available engine visit: [public documentation](https://docs.ovh.com/gb/en/publiccloud/databases).
    :param builtins.str service_name: The id of the public cloud project. If omitted, the `OVH_CLOUD_PROJECT_SERVICE` environment variable is used.
    """
    __args__ = dict()
    __args__['clusterId'] = cluster_id
    __args__['engine'] = engine
    __args__['serviceName'] = service_name
    opts = pulumi.InvokeOutputOptions.merge(_utilities.get_invoke_opts_defaults(), opts)
    __ret__ = pulumi.runtime.invoke_output('ovh:CloudProjectDatabase/getIpRestrictions:getIpRestrictions', __args__, opts=opts, typ=GetIpRestrictionsResult)
    return __ret__.apply(lambda __response__: GetIpRestrictionsResult(
        cluster_id=pulumi.get(__response__, 'cluster_id'),
        engine=pulumi.get(__response__, 'engine'),
        id=pulumi.get(__response__, 'id'),
        ips=pulumi.get(__response__, 'ips'),
        service_name=pulumi.get(__response__, 'service_name')))



# coding=utf-8
# *** WARNING: this file was generated by pulumi-language-python. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import builtins
import copy
import warnings
import sys
import pulumi
import pulumi.runtime
from typing import Any, Mapping, Optional, Sequence, Union, overload
if sys.version_info >= (3, 11):
    from typing import NotRequired, TypedDict, TypeAlias
else:
    from typing_extensions import NotRequired, TypedDict, TypeAlias
from .. import _utilities

__all__ = [
    'GetContainerRegistryOIDCResult',
    'AwaitableGetContainerRegistryOIDCResult',
    'get_container_registry_oidc',
    'get_container_registry_oidc_output',
]

@pulumi.output_type
class GetContainerRegistryOIDCResult:
    """
    A collection of values returned by getContainerRegistryOIDC.
    """
    def __init__(__self__, id=None, oidc_admin_group=None, oidc_auto_onboard=None, oidc_client_id=None, oidc_endpoint=None, oidc_groups_claim=None, oidc_name=None, oidc_scope=None, oidc_user_claim=None, oidc_verify_cert=None, registry_id=None, service_name=None):
        if id and not isinstance(id, str):
            raise TypeError("Expected argument 'id' to be a str")
        pulumi.set(__self__, "id", id)
        if oidc_admin_group and not isinstance(oidc_admin_group, str):
            raise TypeError("Expected argument 'oidc_admin_group' to be a str")
        pulumi.set(__self__, "oidc_admin_group", oidc_admin_group)
        if oidc_auto_onboard and not isinstance(oidc_auto_onboard, bool):
            raise TypeError("Expected argument 'oidc_auto_onboard' to be a bool")
        pulumi.set(__self__, "oidc_auto_onboard", oidc_auto_onboard)
        if oidc_client_id and not isinstance(oidc_client_id, str):
            raise TypeError("Expected argument 'oidc_client_id' to be a str")
        pulumi.set(__self__, "oidc_client_id", oidc_client_id)
        if oidc_endpoint and not isinstance(oidc_endpoint, str):
            raise TypeError("Expected argument 'oidc_endpoint' to be a str")
        pulumi.set(__self__, "oidc_endpoint", oidc_endpoint)
        if oidc_groups_claim and not isinstance(oidc_groups_claim, str):
            raise TypeError("Expected argument 'oidc_groups_claim' to be a str")
        pulumi.set(__self__, "oidc_groups_claim", oidc_groups_claim)
        if oidc_name and not isinstance(oidc_name, str):
            raise TypeError("Expected argument 'oidc_name' to be a str")
        pulumi.set(__self__, "oidc_name", oidc_name)
        if oidc_scope and not isinstance(oidc_scope, str):
            raise TypeError("Expected argument 'oidc_scope' to be a str")
        pulumi.set(__self__, "oidc_scope", oidc_scope)
        if oidc_user_claim and not isinstance(oidc_user_claim, str):
            raise TypeError("Expected argument 'oidc_user_claim' to be a str")
        pulumi.set(__self__, "oidc_user_claim", oidc_user_claim)
        if oidc_verify_cert and not isinstance(oidc_verify_cert, bool):
            raise TypeError("Expected argument 'oidc_verify_cert' to be a bool")
        pulumi.set(__self__, "oidc_verify_cert", oidc_verify_cert)
        if registry_id and not isinstance(registry_id, str):
            raise TypeError("Expected argument 'registry_id' to be a str")
        pulumi.set(__self__, "registry_id", registry_id)
        if service_name and not isinstance(service_name, str):
            raise TypeError("Expected argument 'service_name' to be a str")
        pulumi.set(__self__, "service_name", service_name)

    @property
    @pulumi.getter
    def id(self) -> builtins.str:
        """
        The provider-assigned unique ID for this managed resource.
        """
        return pulumi.get(self, "id")

    @property
    @pulumi.getter(name="oidcAdminGroup")
    def oidc_admin_group(self) -> Optional[builtins.str]:
        """
        Specify an OIDC admin group name. All OIDC users in this group will have harbor admin privilege. Keep it blank if you do not want to.
        """
        return pulumi.get(self, "oidc_admin_group")

    @property
    @pulumi.getter(name="oidcAutoOnboard")
    def oidc_auto_onboard(self) -> Optional[builtins.bool]:
        """
        Skip the onboarding screen, so user cannot change its username. Username is provided from ID Token.
        """
        return pulumi.get(self, "oidc_auto_onboard")

    @property
    @pulumi.getter(name="oidcClientId")
    def oidc_client_id(self) -> Optional[builtins.str]:
        """
        The client ID with which Harbor is registered as client application with the OIDC provider.
        """
        return pulumi.get(self, "oidc_client_id")

    @property
    @pulumi.getter(name="oidcEndpoint")
    def oidc_endpoint(self) -> Optional[builtins.str]:
        """
        The URL of an OIDC-compliant server.
        """
        return pulumi.get(self, "oidc_endpoint")

    @property
    @pulumi.getter(name="oidcGroupsClaim")
    def oidc_groups_claim(self) -> Optional[builtins.str]:
        """
        The name of Claim in the ID token whose value is the list of group names.
        """
        return pulumi.get(self, "oidc_groups_claim")

    @property
    @pulumi.getter(name="oidcName")
    def oidc_name(self) -> Optional[builtins.str]:
        """
        The name of the OIDC provider.
        """
        return pulumi.get(self, "oidc_name")

    @property
    @pulumi.getter(name="oidcScope")
    def oidc_scope(self) -> Optional[builtins.str]:
        """
        The scope sent to OIDC server during authentication. It's a comma-separated string that must contain 'openid' and usually also contains 'profile' and 'email'. To obtain refresh tokens it should also contain 'offline_access'.
        """
        return pulumi.get(self, "oidc_scope")

    @property
    @pulumi.getter(name="oidcUserClaim")
    def oidc_user_claim(self) -> Optional[builtins.str]:
        """
        The name of the claim in the ID Token where the username is retrieved from. If not specified, it will default to 'name' (only useful when automatic Onboarding is enabled).
        """
        return pulumi.get(self, "oidc_user_claim")

    @property
    @pulumi.getter(name="oidcVerifyCert")
    def oidc_verify_cert(self) -> Optional[builtins.bool]:
        """
        Set it to `false` if your OIDC server is hosted via self-signed certificate.
        """
        return pulumi.get(self, "oidc_verify_cert")

    @property
    @pulumi.getter(name="registryId")
    def registry_id(self) -> builtins.str:
        """
        The ID of the Managed Private Registry.
        """
        return pulumi.get(self, "registry_id")

    @property
    @pulumi.getter(name="serviceName")
    def service_name(self) -> builtins.str:
        """
        The ID of the public cloud project. If omitted, the `OVH_CLOUD_PROJECT_SERVICE` environment variable is used.
        """
        return pulumi.get(self, "service_name")


class AwaitableGetContainerRegistryOIDCResult(GetContainerRegistryOIDCResult):
    # pylint: disable=using-constant-test
    def __await__(self):
        if False:
            yield self
        return GetContainerRegistryOIDCResult(
            id=self.id,
            oidc_admin_group=self.oidc_admin_group,
            oidc_auto_onboard=self.oidc_auto_onboard,
            oidc_client_id=self.oidc_client_id,
            oidc_endpoint=self.oidc_endpoint,
            oidc_groups_claim=self.oidc_groups_claim,
            oidc_name=self.oidc_name,
            oidc_scope=self.oidc_scope,
            oidc_user_claim=self.oidc_user_claim,
            oidc_verify_cert=self.oidc_verify_cert,
            registry_id=self.registry_id,
            service_name=self.service_name)


def get_container_registry_oidc(oidc_admin_group: Optional[builtins.str] = None,
                                oidc_auto_onboard: Optional[builtins.bool] = None,
                                oidc_client_id: Optional[builtins.str] = None,
                                oidc_endpoint: Optional[builtins.str] = None,
                                oidc_groups_claim: Optional[builtins.str] = None,
                                oidc_name: Optional[builtins.str] = None,
                                oidc_scope: Optional[builtins.str] = None,
                                oidc_user_claim: Optional[builtins.str] = None,
                                oidc_verify_cert: Optional[builtins.bool] = None,
                                registry_id: Optional[builtins.str] = None,
                                service_name: Optional[builtins.str] = None,
                                opts: Optional[pulumi.InvokeOptions] = None) -> AwaitableGetContainerRegistryOIDCResult:
    """
    Use this data source to get a OVHcloud Managed Private Registry OIDC.

    ## Example Usage

    ```python
    import pulumi
    import pulumi_ovh as ovh

    my_oidc = ovh.CloudProject.get_container_registry_oidc(service_name="XXXXXX",
        registry_id="xxxxxxxx-xxxx-xxxx-xxxx-xxxxxxxx")
    pulumi.export("oidc-client-id", my_oidc.oidc_client_id)
    ```


    :param builtins.str oidc_admin_group: Specify an OIDC admin group name. All OIDC users in this group will have harbor admin privilege. Keep it blank if you do not want to.
    :param builtins.bool oidc_auto_onboard: Skip the onboarding screen, so user cannot change its username. Username is provided from ID Token.
    :param builtins.str oidc_client_id: The client ID with which Harbor is registered as client application with the OIDC provider.
    :param builtins.str oidc_endpoint: The URL of an OIDC-compliant server.
    :param builtins.str oidc_groups_claim: The name of Claim in the ID token whose value is the list of group names.
    :param builtins.str oidc_name: The name of the OIDC provider.
    :param builtins.str oidc_scope: The scope sent to OIDC server during authentication. It's a comma-separated string that must contain 'openid' and usually also contains 'profile' and 'email'. To obtain refresh tokens it should also contain 'offline_access'.
    :param builtins.str oidc_user_claim: The name of the claim in the ID Token where the username is retrieved from. If not specified, it will default to 'name' (only useful when automatic Onboarding is enabled).
    :param builtins.bool oidc_verify_cert: Set it to `false` if your OIDC server is hosted via self-signed certificate.
    :param builtins.str registry_id: The id of the Managed Private Registry.
    :param builtins.str service_name: The id of the public cloud project. If omitted, the `OVH_CLOUD_PROJECT_SERVICE` environment variable is used.
    """
    __args__ = dict()
    __args__['oidcAdminGroup'] = oidc_admin_group
    __args__['oidcAutoOnboard'] = oidc_auto_onboard
    __args__['oidcClientId'] = oidc_client_id
    __args__['oidcEndpoint'] = oidc_endpoint
    __args__['oidcGroupsClaim'] = oidc_groups_claim
    __args__['oidcName'] = oidc_name
    __args__['oidcScope'] = oidc_scope
    __args__['oidcUserClaim'] = oidc_user_claim
    __args__['oidcVerifyCert'] = oidc_verify_cert
    __args__['registryId'] = registry_id
    __args__['serviceName'] = service_name
    opts = pulumi.InvokeOptions.merge(_utilities.get_invoke_opts_defaults(), opts)
    __ret__ = pulumi.runtime.invoke('ovh:CloudProject/getContainerRegistryOIDC:getContainerRegistryOIDC', __args__, opts=opts, typ=GetContainerRegistryOIDCResult).value

    return AwaitableGetContainerRegistryOIDCResult(
        id=pulumi.get(__ret__, 'id'),
        oidc_admin_group=pulumi.get(__ret__, 'oidc_admin_group'),
        oidc_auto_onboard=pulumi.get(__ret__, 'oidc_auto_onboard'),
        oidc_client_id=pulumi.get(__ret__, 'oidc_client_id'),
        oidc_endpoint=pulumi.get(__ret__, 'oidc_endpoint'),
        oidc_groups_claim=pulumi.get(__ret__, 'oidc_groups_claim'),
        oidc_name=pulumi.get(__ret__, 'oidc_name'),
        oidc_scope=pulumi.get(__ret__, 'oidc_scope'),
        oidc_user_claim=pulumi.get(__ret__, 'oidc_user_claim'),
        oidc_verify_cert=pulumi.get(__ret__, 'oidc_verify_cert'),
        registry_id=pulumi.get(__ret__, 'registry_id'),
        service_name=pulumi.get(__ret__, 'service_name'))
def get_container_registry_oidc_output(oidc_admin_group: Optional[pulumi.Input[Optional[builtins.str]]] = None,
                                       oidc_auto_onboard: Optional[pulumi.Input[Optional[builtins.bool]]] = None,
                                       oidc_client_id: Optional[pulumi.Input[Optional[builtins.str]]] = None,
                                       oidc_endpoint: Optional[pulumi.Input[Optional[builtins.str]]] = None,
                                       oidc_groups_claim: Optional[pulumi.Input[Optional[builtins.str]]] = None,
                                       oidc_name: Optional[pulumi.Input[Optional[builtins.str]]] = None,
                                       oidc_scope: Optional[pulumi.Input[Optional[builtins.str]]] = None,
                                       oidc_user_claim: Optional[pulumi.Input[Optional[builtins.str]]] = None,
                                       oidc_verify_cert: Optional[pulumi.Input[Optional[builtins.bool]]] = None,
                                       registry_id: Optional[pulumi.Input[builtins.str]] = None,
                                       service_name: Optional[pulumi.Input[builtins.str]] = None,
                                       opts: Optional[Union[pulumi.InvokeOptions, pulumi.InvokeOutputOptions]] = None) -> pulumi.Output[GetContainerRegistryOIDCResult]:
    """
    Use this data source to get a OVHcloud Managed Private Registry OIDC.

    ## Example Usage

    ```python
    import pulumi
    import pulumi_ovh as ovh

    my_oidc = ovh.CloudProject.get_container_registry_oidc(service_name="XXXXXX",
        registry_id="xxxxxxxx-xxxx-xxxx-xxxx-xxxxxxxx")
    pulumi.export("oidc-client-id", my_oidc.oidc_client_id)
    ```


    :param builtins.str oidc_admin_group: Specify an OIDC admin group name. All OIDC users in this group will have harbor admin privilege. Keep it blank if you do not want to.
    :param builtins.bool oidc_auto_onboard: Skip the onboarding screen, so user cannot change its username. Username is provided from ID Token.
    :param builtins.str oidc_client_id: The client ID with which Harbor is registered as client application with the OIDC provider.
    :param builtins.str oidc_endpoint: The URL of an OIDC-compliant server.
    :param builtins.str oidc_groups_claim: The name of Claim in the ID token whose value is the list of group names.
    :param builtins.str oidc_name: The name of the OIDC provider.
    :param builtins.str oidc_scope: The scope sent to OIDC server during authentication. It's a comma-separated string that must contain 'openid' and usually also contains 'profile' and 'email'. To obtain refresh tokens it should also contain 'offline_access'.
    :param builtins.str oidc_user_claim: The name of the claim in the ID Token where the username is retrieved from. If not specified, it will default to 'name' (only useful when automatic Onboarding is enabled).
    :param builtins.bool oidc_verify_cert: Set it to `false` if your OIDC server is hosted via self-signed certificate.
    :param builtins.str registry_id: The id of the Managed Private Registry.
    :param builtins.str service_name: The id of the public cloud project. If omitted, the `OVH_CLOUD_PROJECT_SERVICE` environment variable is used.
    """
    __args__ = dict()
    __args__['oidcAdminGroup'] = oidc_admin_group
    __args__['oidcAutoOnboard'] = oidc_auto_onboard
    __args__['oidcClientId'] = oidc_client_id
    __args__['oidcEndpoint'] = oidc_endpoint
    __args__['oidcGroupsClaim'] = oidc_groups_claim
    __args__['oidcName'] = oidc_name
    __args__['oidcScope'] = oidc_scope
    __args__['oidcUserClaim'] = oidc_user_claim
    __args__['oidcVerifyCert'] = oidc_verify_cert
    __args__['registryId'] = registry_id
    __args__['serviceName'] = service_name
    opts = pulumi.InvokeOutputOptions.merge(_utilities.get_invoke_opts_defaults(), opts)
    __ret__ = pulumi.runtime.invoke_output('ovh:CloudProject/getContainerRegistryOIDC:getContainerRegistryOIDC', __args__, opts=opts, typ=GetContainerRegistryOIDCResult)
    return __ret__.apply(lambda __response__: GetContainerRegistryOIDCResult(
        id=pulumi.get(__response__, 'id'),
        oidc_admin_group=pulumi.get(__response__, 'oidc_admin_group'),
        oidc_auto_onboard=pulumi.get(__response__, 'oidc_auto_onboard'),
        oidc_client_id=pulumi.get(__response__, 'oidc_client_id'),
        oidc_endpoint=pulumi.get(__response__, 'oidc_endpoint'),
        oidc_groups_claim=pulumi.get(__response__, 'oidc_groups_claim'),
        oidc_name=pulumi.get(__response__, 'oidc_name'),
        oidc_scope=pulumi.get(__response__, 'oidc_scope'),
        oidc_user_claim=pulumi.get(__response__, 'oidc_user_claim'),
        oidc_verify_cert=pulumi.get(__response__, 'oidc_verify_cert'),
        registry_id=pulumi.get(__response__, 'registry_id'),
        service_name=pulumi.get(__response__, 'service_name')))



# coding=utf-8
# *** WARNING: this file was generated by pulumi-language-python. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import builtins
import copy
import warnings
import sys
import pulumi
import pulumi.runtime
from typing import Any, Mapping, Optional, Sequence, Union, overload
if sys.version_info >= (3, 11):
    from typing import NotRequired, TypedDict, TypeAlias
else:
    from typing_extensions import NotRequired, TypedDict, TypeAlias
from .. import _utilities

__all__ = [
    'GetIdentityUserResult',
    'AwaitableGetIdentityUserResult',
    'get_identity_user',
    'get_identity_user_output',
]

@pulumi.output_type
class GetIdentityUserResult:
    """
    A collection of values returned by getIdentityUser.
    """
    def __init__(__self__, user_urn=None, creation=None, description=None, email=None, group=None, id=None, last_update=None, login=None, password_last_update=None, status=None, user=None):
        if user_urn and not isinstance(user_urn, str):
            raise TypeError("Expected argument 'user_urn' to be a str")
        pulumi.set(__self__, "user_urn", user_urn)
        if creation and not isinstance(creation, str):
            raise TypeError("Expected argument 'creation' to be a str")
        pulumi.set(__self__, "creation", creation)
        if description and not isinstance(description, str):
            raise TypeError("Expected argument 'description' to be a str")
        pulumi.set(__self__, "description", description)
        if email and not isinstance(email, str):
            raise TypeError("Expected argument 'email' to be a str")
        pulumi.set(__self__, "email", email)
        if group and not isinstance(group, str):
            raise TypeError("Expected argument 'group' to be a str")
        pulumi.set(__self__, "group", group)
        if id and not isinstance(id, str):
            raise TypeError("Expected argument 'id' to be a str")
        pulumi.set(__self__, "id", id)
        if last_update and not isinstance(last_update, str):
            raise TypeError("Expected argument 'last_update' to be a str")
        pulumi.set(__self__, "last_update", last_update)
        if login and not isinstance(login, str):
            raise TypeError("Expected argument 'login' to be a str")
        pulumi.set(__self__, "login", login)
        if password_last_update and not isinstance(password_last_update, str):
            raise TypeError("Expected argument 'password_last_update' to be a str")
        pulumi.set(__self__, "password_last_update", password_last_update)
        if status and not isinstance(status, str):
            raise TypeError("Expected argument 'status' to be a str")
        pulumi.set(__self__, "status", status)
        if user and not isinstance(user, str):
            raise TypeError("Expected argument 'user' to be a str")
        pulumi.set(__self__, "user", user)

    @property
    @pulumi.getter(name="UserURN")
    def user_urn(self) -> builtins.str:
        """
        User's identity URN.
        """
        return pulumi.get(self, "user_urn")

    @property
    @pulumi.getter
    def creation(self) -> builtins.str:
        """
        Creation date of this user.
        """
        return pulumi.get(self, "creation")

    @property
    @pulumi.getter
    def description(self) -> builtins.str:
        """
        User description.
        """
        return pulumi.get(self, "description")

    @property
    @pulumi.getter
    def email(self) -> builtins.str:
        """
        User's email.
        """
        return pulumi.get(self, "email")

    @property
    @pulumi.getter
    def group(self) -> builtins.str:
        """
        User's group.
        """
        return pulumi.get(self, "group")

    @property
    @pulumi.getter
    def id(self) -> builtins.str:
        """
        The provider-assigned unique ID for this managed resource.
        """
        return pulumi.get(self, "id")

    @property
    @pulumi.getter(name="lastUpdate")
    def last_update(self) -> builtins.str:
        """
        Last update of this user.
        """
        return pulumi.get(self, "last_update")

    @property
    @pulumi.getter
    def login(self) -> builtins.str:
        """
        User's login suffix.
        """
        return pulumi.get(self, "login")

    @property
    @pulumi.getter(name="passwordLastUpdate")
    def password_last_update(self) -> builtins.str:
        """
        When the user changed his password for the last time.
        """
        return pulumi.get(self, "password_last_update")

    @property
    @pulumi.getter
    def status(self) -> builtins.str:
        """
        Current user's status.
        """
        return pulumi.get(self, "status")

    @property
    @pulumi.getter
    def user(self) -> builtins.str:
        return pulumi.get(self, "user")


class AwaitableGetIdentityUserResult(GetIdentityUserResult):
    # pylint: disable=using-constant-test
    def __await__(self):
        if False:
            yield self
        return GetIdentityUserResult(
            user_urn=self.user_urn,
            creation=self.creation,
            description=self.description,
            email=self.email,
            group=self.group,
            id=self.id,
            last_update=self.last_update,
            login=self.login,
            password_last_update=self.password_last_update,
            status=self.status,
            user=self.user)


def get_identity_user(user: Optional[builtins.str] = None,
                      opts: Optional[pulumi.InvokeOptions] = None) -> AwaitableGetIdentityUserResult:
    """
    Use this data source to retrieve information about an identity user.

    ## Example Usage

    ```python
    import pulumi
    import pulumi_ovh as ovh

    my_user = ovh.Me.get_identity_user(user="my_user_login")
    ```


    :param builtins.str user: User's login.
    """
    __args__ = dict()
    __args__['user'] = user
    opts = pulumi.InvokeOptions.merge(_utilities.get_invoke_opts_defaults(), opts)
    __ret__ = pulumi.runtime.invoke('ovh:Me/getIdentityUser:getIdentityUser', __args__, opts=opts, typ=GetIdentityUserResult).value

    return AwaitableGetIdentityUserResult(
        user_urn=pulumi.get(__ret__, 'user_urn'),
        creation=pulumi.get(__ret__, 'creation'),
        description=pulumi.get(__ret__, 'description'),
        email=pulumi.get(__ret__, 'email'),
        group=pulumi.get(__ret__, 'group'),
        id=pulumi.get(__ret__, 'id'),
        last_update=pulumi.get(__ret__, 'last_update'),
        login=pulumi.get(__ret__, 'login'),
        password_last_update=pulumi.get(__ret__, 'password_last_update'),
        status=pulumi.get(__ret__, 'status'),
        user=pulumi.get(__ret__, 'user'))
def get_identity_user_output(user: Optional[pulumi.Input[builtins.str]] = None,
                             opts: Optional[Union[pulumi.InvokeOptions, pulumi.InvokeOutputOptions]] = None) -> pulumi.Output[GetIdentityUserResult]:
    """
    Use this data source to retrieve information about an identity user.

    ## Example Usage

    ```python
    import pulumi
    import pulumi_ovh as ovh

    my_user = ovh.Me.get_identity_user(user="my_user_login")
    ```


    :param builtins.str user: User's login.
    """
    __args__ = dict()
    __args__['user'] = user
    opts = pulumi.InvokeOutputOptions.merge(_utilities.get_invoke_opts_defaults(), opts)
    __ret__ = pulumi.runtime.invoke_output('ovh:Me/getIdentityUser:getIdentityUser', __args__, opts=opts, typ=GetIdentityUserResult)
    return __ret__.apply(lambda __response__: GetIdentityUserResult(
        user_urn=pulumi.get(__response__, 'user_urn'),
        creation=pulumi.get(__response__, 'creation'),
        description=pulumi.get(__response__, 'description'),
        email=pulumi.get(__response__, 'email'),
        group=pulumi.get(__response__, 'group'),
        id=pulumi.get(__response__, 'id'),
        last_update=pulumi.get(__response__, 'last_update'),
        login=pulumi.get(__response__, 'login'),
        password_last_update=pulumi.get(__response__, 'password_last_update'),
        status=pulumi.get(__response__, 'status'),
        user=pulumi.get(__response__, 'user')))



# coding=utf-8
# *** WARNING: this file was generated by pulumi-language-python. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import builtins
from .. import _utilities
import typing
# Export this package's modules as members:
from .get_permissions_group import *
from .get_permissions_groups import *
from .get_policies import *
from .get_policy import *
from .get_reference_actions import *
from .get_reference_resource_type import *
from .get_resource_group import *
from .get_resource_groups import *
from .permissions_group import *
from .policy import *
from .resource_group import *
from . import outputs
